<?php

namespace Faker\Provider\lv_LV;

use Faker\Provider\DateTime;

class Person extends \Faker\Provider\Person
{
    /**
     * {@link} http://vardunozime.lv/names-male
     */
    protected static $firstNameMale = [
        'Acons', 'Adalberts', 'Adelions', 'Adeljans', 'Adeļjons', 'Adgars', 'Adis', 'Ado', 'Adonis', 'Adoniss', 'Adrians', 'Adriāns', 'Adris', 'Afanasijs', 'Agatons', 'Agejs', 'Agijs', 'Aģis', 'Agnārs', 'Agnis', 'Agris', 'Agrits', 'Agrons', 'Agurs', 'Ahmads', 'Ahmeds', 'Ahto', 'Aidars', 'Aidis', 'Aigars', 'Aigijs', 'Aigils', 'Aigis', 'Aigo', 'Aigvars', 'Ailands', 'Aimo', 'Ainards', 'Ainārs', 'Ainars', 'Ainis', 'Aino', 'Airats', 'Airiks', 'Airis', 'Airtons', 'Aivalds', 'Aivars', 'Aivārs', 'Aivijs', 'Aivils', 'Aivis', 'Aivo', 'Akims', 'Ako', 'Akselis', 'Aksels', 'Alans', 'Alberts', 'Albīns', 'Albins', 'Aldijs', 'Aldis', 'Aldonis', 'Aldons', 'Aldris', 'Aleksandris', 'Aleksandrs', 'Aleksejs', 'Aleksis', 'Alekss', 'Alens', 'Alēns', 'Alereins', 'Alesandrs', 'Alfejs', 'Alfijs', 'Alfins', 'Alfons', 'Alfonss', 'Alfrēds', 'Alfreds', 'Alfrīds', 'Alfrids', 'Alfs', 'Algarts', 'Algers', 'Alģerts', 'Alģimants', 'Aļģirds', 'Algirds', 'Alģirds', 'Aļģirts', 'Alģirts', 'Alģis', 'Aļģis', 'Aliks', 'Aļiks', 'Alis', 'Alisters', 'Allans', 'Allens', 'Almands', 'Almants', 'Almārs', 'Almonds', 'Alnars', 'Alnis', 'Alnors', 'Aloīzijs', 'Aloizis', 'Aloizs', 'Aloīzs', 'Alons', 'Alsis', 'Altairs', 'Alvaro', 'Alvars', 'Alvids', 'Alvijs', 'Alvils', 'Alvīns', 'Alvis', 'Alvits', 'Amandis', 'Amands', 'Ambrozijs', 'Amijs', 'Amirans', 'Amirs', 'Amunds', 'Anārs', 'Anastāsijs', 'Anastāzijs', 'Anatolijs', 'Anatols', 'Ancis', 'Andars', 'Andejs', 'Anders', 'Anderss', 'Andijs', 'Andis', 'Ando', 'Andreass', 'Andrejans', 'Andrejs', 'Andrējs', 'Andress', 'Andriāns', 'Andrievs', 'Andrijans', 'Andrijs', 'Andris', 'Androns', 'Andrs', 'Andrus', 'Andruss', 'Andulis', 'Andžejs', 'Andzelms', 'Andželo', 'Andžs', 'Anfims', 'Angarijs', 'Anicets', 'Anis', 'Anrī', 'Anrijs', 'Anris', 'Anriss', 'Anselms', 'Ansis', 'Anšlavs', 'Antans', 'Antars', 'Antis', 'Antonijs', 'Antonio', 'Antons', 'Antris', 'Ants', 'Antuans', 'Anufrijs', 'Anvars', 'Anzelms', 'Anžijs', 'Apolinārijs', 'Apolinārs', 'Apolons', 'Aralds', 'Arams', 'Arčijs', 'Arčils', 'Ardis', 'Ards', 'Aress', 'Aretijs', 'Arets', 'Argils', 'Argo', 'Argods', 'Argons', 'Argots', 'Arguts', 'Arialds', 'Arians', 'Ariels', 'Arigo', 'Arijs', 'Ariko', 'Arilds', 'Arimands', 'Arīns', 'Arions', 'Aris', 'Ariss', 'Aristīds', 'Aristons', 'Arkādijs', 'Arlijs', 'Armando', 'Armands', 'Armanis', 'Armans', 'Armants', 'Armass', 'Armens', 'Armīds', 'Armīns', 'Armins', 'Armis', 'Arnis', 'Arno', 'Arnolds', 'Arnotijs', 'Arnulfs', 'Arsenijs', 'Arsēnijs', 'Arsens', 'Arsēns', 'Arsentijs', 'Artemijs', 'Artēmijs', 'Artijs', 'Artiks', 'Artis', 'Artjoms', 'Arts', 'Artūrs', 'Arturs', 'Arvalds', 'Arveds', 'Arvēds', 'Arvīds', 'Arvids', 'Arvils', 'Arvīns', 'Arvis', 'Arvo', 'Askolds', 'Asmunds', 'Astērijs', 'Astrīds', 'Atāls', 'Atanazijs', 'Atis', 'Atstars', 'Atvars', 'Audars', 'Audris', 'Augmants', 'Augustīns', 'Augusts', 'Aurelijs', 'Aurēlijs', 'Aurels', 'Auseklis', 'Ausmis', 'Ausmunds', 'Austris', 'Austrums',
        'Ādams', 'Ādolfs', 'Ārends', 'Ārens', 'Ārijs', 'Āriks', 'Āris', 'Ārons', 'Ārvaldis', 'Ārvalds', 'Āvo',
        'Baldūrs', 'Balvis', 'Bartolomejs', 'Bārtulis', 'Bazils', 'Bendžamins', 'Benedikts', 'Benijs', 'Benito', 'Benjāmiņš', 'Benjamins', 'Benno', 'Beno', 'Bens', 'Berils', 'Bernads', 'Bernards', 'Bernārs', 'Bernats', 'Bernhards', 'Bertolds', 'Bertrams', 'Berts', 'Bērtulis', 'Bierants', 'Billijs', 'Bils', 'Bogdans', 'Boļeslavs', 'Bonaventūrs', 'Bonifācijs', 'Bonifātijs', 'Bonifats', 'Bonijs', 'Borislavs', 'Boriss', 'Braiens', 'Braijens', 'Brains', 'Brencis', 'Brendons', 'Brets', 'Bronis', 'Broņislavs', 'Bronislavs', 'Brunis', 'Bruno', 'Brunons', 'Brūss',
        'Čariijs', 'Čarlzs', 'Česlavs',
        'Censonis', 'Censons', 'Centis', 'Centonis', 'Ceronis', 'Cerons', 'Cēzars', 'Cezars', 'Cildis', 'Cildonis', 'Ciprians', 'Ciprijans',
        'Dabris', 'Dacis', 'Dadzis', 'Dafnis', 'Dagmārs', 'Dagnijs', 'Dagnis', 'Dāgs', 'Dags', 'Daiens', 'Daigars', 'Daigonis', 'Dailis', 'Dailonis', 'Dailons', 'Daimonds', 'Daimons', 'Dainārs', 'Dainarts', 'Dainis', 'Dainors', 'Dairis', 'Daivis', 'Damārs', 'Damirs', 'Danats', 'Daneks', 'Dāniels', 'Daniēls', 'Daniels', 'Daniils', 'Daņiils', 'Danijs', 'Daņils', 'Danils', 'Danis', 'Danko', 'Dans', 'Dārgs', 'Dārijs', 'Daris', 'Dato', 'Daumands', 'Daumants', 'Dāvids', 'Dāvīds', 'Dāvis', 'Dāvs', 'Deils', 'Deimonds', 'Deimons', 'Deinis', 'Deins', 'Deivids', 'Deivijs', 'Deivis', 'Deivs', 'Dementijs', 'Deniels', 'Denijs', 'Deņiss', 'Deniss', 'Dens', 'Dēvids', 'Dēvijs', 'Didrihs', 'Didriķis', 'Didzis', 'Didžus', 'Digmārs', 'Dijs', 'Dikijs', 'Diks', 'Dimants', 'Dimārs', 'Dimitrijs', 'Dinards', 'Dinārs', 'Dinijs', 'Dinis', 'Dino', 'Dins', 'Dīns', 'Dionisijs', 'Dionizijs', 'Dīters', 'Ditmārs', 'Dmitrijs', 'Domeniks', 'Dominiks', 'Donalds', 'Donats', 'Donāts', 'Dravis', 'Drosmiņš', 'Drosmis', 'Drošvaldis', 'Drošvaris', 'Druvaldis', 'Druvalds', 'Druvārs', 'Druvinalds', 'Druvis', 'Druvvaldis', 'Druvvalds', 'Džastins', 'Džeims', 'Džeimss', 'Džems', 'Džemss', 'Džeralds', 'Džerijs', 'Dzidris', 'Dzilvars', 'Džims', 'Dzintars', 'Dzintārs', 'Dzintis', 'Dzintris', 'Džo', 'Džonatans', 'Džonijs', 'Džonis', 'Džons', 'Džordans', 'Džordijs', 'Džordžs',
        'Eberhards', 'Edgards', 'Edgars', 'Edgārs', 'Edijs', 'Ediks', 'Edilberts', 'Edis', 'Edmans', 'Edmārs', 'Edmonds', 'Edmons', 'Edmunds', 'Edmunts', 'Eduards', 'Eduārds', 'Eduars', 'Edvards', 'Edvārts', 'Edvijs', 'Edvīns', 'Edvins', 'Edžus', 'Egberts', 'Egdijs', 'Egerts', 'Egidijs', 'Egijs', 'Egīls', 'Egils', 'Eginhards', 'Egīns', 'Egits', 'Eglis', 'Eglons', 'Egmārs', 'Egmonds', 'Egmonts', 'Egnārs', 'Ego', 'Egons', 'Eidis', 'Eigits', 'Einards', 'Einārs', 'Einars', 'Einarts', 'Einis', 'Eino', 'Eiženijs', 'Eižens', 'Elands', 'Elāns', 'Elārs', 'Elčins', 'Eldars', 'Eldijs', 'Elens', 'Elerts', 'Elfrīds', 'Elgars', 'Elgasts', 'Elgons', 'Eliass', 'Eliašs', 'Elijass', 'Elijašs', 'Elijs', 'Elīns', 'Elīss', 'Eljašs', 'Elmārs', 'Elmars', 'Elmo', 'Elmonds', 'Elmuts', 'Elnurs', 'Eltons', 'Elvars', 'Elvigs', 'Elvijs', 'Elvings', 'Elvīns', 'Elvīrs', 'Elvis', 'Elviss', 'Elvo', 'Emanuels', 'Emanuils', 'Emeralds', 'Emerihs', 'Emeriks', 'Emijs', 'Emilians', 'Emilijans', 'Emīlijs', 'Emīlis', 'Emiljans', 'Emīls', 'Emils', 'Emmanuels', 'Enārs', 'Endijs', 'Endo', 'Endrijs', 'Engelberts', 'Engus', 'Enijs', 'Enno', 'Enoks', 'Enrijs', 'Enriko', 'Enriks', 'Eralds', 'Erasts', 'Erberts', 'Erhards', 'Eriands', 'Eriens', 'Erihs', 'Eriks', 'Erims', 'Erlends', 'Ermanis', 'Ermans', 'Ermīns', 'Ernando', 'Ernests', 'Ernis', 'Ernsts', 'Ero', 'Ervids', 'Ervijs', 'Ervils', 'Ervīns', 'Ervins', 'Ervis', 'Esams', 'Etjēns', 'Euģenijs', 'Euģēnijs', 'Eugenijs', 'Eugēnijs', 'Euzebijs', 'Evalds', 'Evarists', 'Evars', 'Evarts', 'Eventijs', 'Everts', 'Evgēnijs', 'Evgenijs', 'Evģēnijs', 'Evģenijs', 'Evijs',
        'Ērihs', 'Ēriks', 'Ērmanis', 'Ēro', 'Ēvalds',
        'Fabiāns', 'Fabijāns', 'Fadejs', 'Falks', 'Farhads', 'Farids', 'Fedors', 'Fedots', 'Felicians', 'Felicijans', 'Fēlikss', 'Felikss', 'Feodors', 'Ferdinands', 'Ferencs', 'Ferijs', 'Fernands', 'FīIips', 'Filips', 'Fjodors', 'Floriāns', 'Florijans', 'Florijs', 'Francis', 'Francišeks', 'Francisks', 'Francs', 'Franeks', 'Franks', 'Franļišeks', 'Frederiks', 'Fredijs', 'Fredis', 'Freds', 'Frementijs', 'Frenks', 'Fricis', 'Fridberts', 'Frideriks', 'Frīdis', 'Fridis', 'Frīdrihs', 'Fritjofs',
        'Gabriels', 'Gabriēls', 'Gaidars', 'Gaidis', 'Gaidonis', 'Gaidvars', 'Gaismonis', 'Gaismons', 'Gaitis', 'Gaits', 'Garlībs', 'Gastons', 'Gatiņš', 'Gatis', 'Gavrils', 'Gedimins', 'Gelārijs', 'Genādijs', 'Gennādijs', 'Georgijs', 'Georgs', 'Geralds', 'Gerards', 'Gerasims', 'Gerds', 'Gerhards', 'Geronīms', 'Gerts', 'Gido', 'Gidons', 'Gijs', 'Gilarijs', 'Gilberts', 'Ginārs', 'Gintārs', 'Gintauts', 'Ginters', 'Gintis', 'Gints', 'Gits', 'Gļebs', 'Glens', 'Godfrīds', 'Godvars', 'Gordejs', 'Gorijs', 'Gotards', 'Gotfrīds', 'Gothards', 'Gracijans', 'Grants', 'Grats', 'Gregors', 'Grigorijs', 'Grigors', 'Gudmunds', 'Gunards', 'Gunārs', 'Gunars', 'Gunarts', 'Gundaris', 'Gundars', 'Gundis', 'Gundolfs', 'Gunis', 'Gunivaldis', 'Gunivalds', 'Gunnars', 'Guno', 'Guntars', 'Guntārs', 'Guntis', 'Guntris', 'Gunts', 'Gunvaldis', 'Gunvalds', 'Gunvaris', 'Gunvars', 'Gurijs', 'Gustavs', 'Gusts', 'Gutars', 'Gvidis', 'Gvido', 'Gvidons',
        'Ģederts', 'Ģedimins', 'Ģintars', 'Ģints', 'Ģirts',
        'Haldons', 'Haldors', 'Hamilkārs', 'Hanss', 'Haralds', 'Hārdijs', 'Hardis', 'Harijs', 'Haris', 'Haritons', 'Harlijs', 'Harolds', 'Hartvigs', 'Harvijs', 'Hedijs', 'Hedvigs', 'Heincs', 'Heindrihs', 'Heinis', 'Heino', 'Heinrihs', 'Heinriks', 'Heldurs', 'Helijs', 'Heliodors', 'Helmārs', 'Helmī', 'Helmuts', 'Helmūts', 'Helvigs', 'Helvijs', 'Helvis', 'Hendrihs', 'Hendriks', 'Henno', 'Henrihs', 'Henrijs', 'Henriks', 'Herberts', 'Hermanis', 'Hermans', 'Hermunds', 'Herolds', 'Heronīms', 'Hevijs', 'Hieronims', 'Higo', 'Hilards', 'Hilārijs', 'Hilārs', 'Hilmārs', 'Hipolits', 'Holgers', 'Honorads', 'Horens', 'Horsts', 'Huans', 'Hūberts', 'Hugo',
        'Ievalds', 'Igars', 'Igmārs', 'Ignars', 'Ignātijs', 'Ignats', 'Ignāts', 'Igo', 'Igors', 'Igvars', 'Ihtiandrs', 'Ikars', 'Ilards', 'Ilārijs', 'Ilārs', 'Ildars', 'Ildefons', 'Ilgards', 'Ilgārs', 'Ilgarts', 'Ilgmārs', 'Ilgmars', 'Ilgonis', 'Ilgons', 'Ilgvalds', 'Ilgvards', 'Ilgvaris', 'Ilgvars', 'Ilgvārs', 'Illo', 'Ilmārs', 'Ilmars', 'Ilo', 'Ilons', 'Ilvars', 'Ilvārs', 'Ilvers', 'Ilvis', 'Imants', 'Imanuels', 'Imārs', 'Imarts', 'Inārijs', 'Inārs', 'Inars', 'Inarts', 'Indars', 'Indriķis', 'Indriks', 'Indris', 'Indulis', 'Induls', 'Inesis', 'Ingars', 'Ingārs', 'Ingemārs', 'Ingerts', 'Ingmārs', 'Ingmars', 'Ingo', 'Ingolfs', 'Ingomars', 'Inguards', 'Inguns', 'Ingūns', 'Ingurds', 'Ingurs', 'Ingus', 'Inguss', 'Ingvards', 'Ingvars', 'Ingvilds', 'Inmārs', 'Innocentijs', 'Ino', 'Inolds', 'Inrigo', 'Intars', 'Intārs', 'Intis', 'Ints', 'Invalds', 'Invars', 'Ipolits', 'Iraidis', 'Iraklijs', 'Irenejs', 'Irenijs', 'Irēnijs', 'Irinejs', 'Irmants', 'Ironijs', 'Irvalds', 'Irvings', 'Irvīns', 'Ismails', 'Itallo', 'Itālo', 'Itārs', 'Itvars', 'Ivalds', 'Ivans', 'Ivars', 'Ivārs', 'Iverts', 'Ivis', 'Ivo', 'Ivs', 'Izidors',
        'Īvis',
        'Jaceks', 'Jakims', 'Jakobs', 'Jakovs', 'Jākubs', 'Jalmars', 'Janeks', 'Jānis', 'Janis', 'Janošs', 'Jāns', 'Janušs', 'Jaroslavs', 'Jautris', 'Jāzeps', 'Jazeps', 'Jefims', 'Jegors', 'Jēkabs', 'Jelisejs', 'Jemeļjans', 'Jermolajs', 'Jeronīms', 'Jeroslavs', 'Jevgēņijs', 'Jevgēnijs', 'Jevgeņijs', 'Jevgenijs', 'Jevģēnijs', 'Jevģenijs', 'Jēzups', 'Jezups', 'Joahims', 'Joakims', 'Joans', 'Johans', 'Jolands', 'Jolants', 'Jonatāns', 'Jonijs', 'Jons', 'Jordans', 'Jorens', 'Jorēns', 'Jovars', 'Jozefs', 'Jozs', 'Juhans', 'Jukums', 'Juliāns', 'Jūliāns', 'Jūlijans', 'Jūlijs', 'Julijs', 'Jūliuss', 'Juļjāns', 'Jumis', 'Jūnijs', 'Jurands', 'Jureks', 'Jurģis', 'Jurijs', 'Juriks', 'Juris', 'Jūris', 'Jūsmiņš', 'Justīns', 'Justs', 'Jūtvaldis', 'Juvents', 'Juzefs',
        'Kaido', 'Kaivis', 'Kajs', 'Kālebs', 'Kaliksts', 'Kalins', 'Kalvis', 'Kamils', 'Kardijs', 'Karels', 'Karens', 'Karims', 'Kārlis', 'Karolis', 'Karols', 'Karps', 'Kaspars', 'Kazemirs', 'Kazimirs', 'Kazis', 'Kazmers', 'Keits', 'Kenets', 'Kerijs', 'Kestutis', 'Kevins', 'Kims', 'Kirils', 'Klaidis', 'Klaids', 'Klāss', 'Klaudijs', 'Klāvs', 'Klemans', 'Klemens', 'Klemenss', 'Klementijs', 'Klementīns', 'Klements', 'Klimans', 'Klimentijs', 'Klods', 'Knuts', 'Komēlijs', 'Kondrāts', 'Konrāds', 'Konrads', 'Konrands', 'Konrāts', 'Konstantīns', 'Konstantins', 'Kornelijs', 'Kreigs', 'Krišjānis', 'Krišjāns', 'Krišs', 'Kristafors', 'Kristaps', 'Kristars', 'Kristens', 'Kristers', 'Kristiāns', 'Kristians', 'Kristijāns', 'Kristjānis', 'Kristjans', 'Kristo', 'Kristofers', 'Kristofors', 'Kristofs', 'Krists', 'Krišus', 'Krīvs', 'Ksaverijs', 'Ksavērijs', 'Ksavers', 'Kuno', 'Kurbads', 'Kurbats', 'Kurts',
        'Labrencis', 'Lāčplēsis', 'Ladislavs', 'Laimdotis', 'Laimdots', 'Laimiņš', 'Laimis', 'Laimnesis', 'Laimonds', 'Laimonis', 'Laimons', 'Laimonts', 'Laimstars', 'Laimutis', 'Laimzieds', 'Lainis', 'Landijs', 'Larijs', 'Larions', 'Laris', 'Lars', 'Larss', 'Lato', 'Latvis', 'Laurentijs', 'Laurijs', 'Lauris', 'Lavrentijs', 'Leino', 'Lenards', 'Lenārs', 'Lenarts', 'Lennijs', 'Leo', 'Leonardo', 'Leonards', 'Leonārs', 'Leongīns', 'Leonhards', 'Leonīds', 'Leonids', 'Leons', 'Leontijs', 'Leontīns', 'Leopolds', 'Levijs', 'Liards', 'Liberijs', 'Līgonis', 'Līgotnis', 'Lilians', 'Linards', 'Linārs', 'Linarts', 'Lindons', 'Linerts', 'Lins', 'Linus', 'Linuss', 'Livars', 'Līvis', 'Līvs', 'Lonards', 'Lonarts', 'Longins', 'Lorands', 'Lorens', 'Lorenss', 'Lorijs', 'Lotārs', 'Lotars', 'Luciāns', 'Lucijāns', 'Ludis', 'Lūdolfs', 'Ludoviks', 'Ludvigs', 'Ludviķis', 'Ludviks', 'Luijs', 'Luiss', 'Lūkass',
        'Ļevs',
        'Madars', 'Madis', 'Magnus', 'Magnuss', 'Maigonis', 'Maigons', 'Maigurs', 'Maikls', 'Maiks', 'Mairis', 'Mairolds', 'Mairs', 'Maksimiliāns', 'Maksims', 'Maksis', 'Makss', 'Maldis', 'Maldonis', 'Malvis', 'Mamerts', 'Manfreds', 'Manfrēds', 'Marats', 'Mārcis', 'Marcis', 'Mareks', 'Marģeris', 'Marģers', 'Marģis', 'Margo', 'Margonis', 'Margons', 'Margots', 'Marguss', 'Marguts', 'Marians', 'Mariens', 'Marijans', 'Mārijs', 'Mariks', 'Mario', 'Māris', 'Maris', 'Mariss', 'Mariuss', 'Marjans', 'Marjus', 'Marko', 'Marks', 'Markus', 'Markuss', 'Maro', 'Marsels', 'Mārtiņš', 'Martins', 'Martiņs', 'Marts', 'Mārts', 'Mateass', 'Matejs', 'Mateuss', 'Mateušs', 'Matiass', 'Matis', 'Matīss', 'Matvejs', 'Maurīcijs', 'Mečeslavs', 'Mečislavs', 'Medards', 'Medarts', 'Mefodijs', 'Meikols', 'Meikulis', 'Meikuls', 'Meinards', 'Meinhards', 'Meldris', 'Mereks', 'Mervils', 'Metjū', 'Metodijs', 'Mežvaldis', 'Mieriņš', 'Miermīlis', 'Miernesis', 'Miervaldis', 'Miervalds', 'Mihaels', 'Mihails', 'Mikaels', 'Miķelis', 'Miķēlis', 'Miks', 'Mikus', 'Milāns', 'Milvards', 'Milvars', 'Mindaugs', 'Mintauts', 'Miroslavs', 'Mišels', 'Modests', 'Modis', 'Modrinš', 'Modris', 'Montis', 'Monts', 'Monvīds', 'Monvids', 'Morics', 'Moriss', 'Mudijs', 'Mudiņš', 'Mudis', 'Mudris', 'Mundis', 'Mundris', 'Muntis', 'Murads', 'Muslims',
        'Naidžels', 'Nameisis', 'Namejs', 'Napoleons', 'Narciss', 'Nareks', 'Narimans', 'Narimants', 'Natans', 'Nauris', 'Neils', 'Nesters', 'Nestors', 'Nevils', 'Nikandrs', 'Nikifors', 'Nikijs', 'Niklāss', 'Niklāvs', 'Niklavs', 'Niko', 'Nikodems', 'Nikodēms', 'Nikodims', 'Nikolajs', 'Nikolass', 'Niks', 'Nils', 'Nīls', 'Nilss', 'Nolāns', 'Noldis', 'Norberts', 'Nords', 'Noris', 'Norītis', 'Norlands', 'Normands', 'Normans', 'Normants', 'Normens', 'Normuds', 'Normunds',
        'Ņikifors', 'Ņikita',
        'Odisejs', 'Odums', 'Ogists', 'Ojārs', 'Oktavians', 'Olafs', 'Olands', 'Olārs', 'Olavs', 'Oļegs', 'Olevs', 'Olģerds', 'Oļģerts', 'Olgerts', 'Olis', 'Olivers', 'Olmars', 'Omārs', 'Oniks', 'Ontons', 'Onufrijs', 'Orests', 'Orfejs', 'Ornets', 'Ortando', 'Osips', 'Oskars', 'Osmars', 'Ostins', 'Osvaldis', 'Osvalds', 'Otārs', 'Otis', 'Oto', 'Otomārs', 'Otomars',
        'Patricijs', 'Patriks', 'Paulis', 'Pauls', 'Pāvels', 'Pāvils', 'Pavils', 'Pāvuls', 'Pērs', 'Persijs', 'Pēteris', 'Pēters', 'Petro', 'Petrs', 'Pijs', 'Pīters', 'Pits', 'Pius', 'Pjotrs', 'Platons', 'Plūdonis', 'Polikarps', 'Pols', 'Prans',
        'Radimins', 'Radions', 'Radislavs', 'Radomirs', 'Radvilis', 'Radvils', 'Rafaels', 'Rafaēls', 'Rafails', 'Rafiks', 'Ragnārs', 'Rahmats', 'Raiders', 'Raido', 'Raiens', 'Raigards', 'Raigo', 'Railands', 'Raimis', 'Raimo', 'Raimonds', 'Raimons', 'Raimunds', 'Rainars', 'Rainers', 'Rainis', 'Rainolds', 'Raitis', 'Raits', 'Raivis', 'Raivo', 'Raldis', 'Ralfs', 'Ramērs', 'Ramils', 'Ramiro', 'Ramons', 'Randolfs', 'Rašids', 'Rasmuss', 'Raulis', 'Rauls', 'Reds', 'Redženalds', 'Redžinalds', 'Reginalds', 'Regīns', 'Regnalds', 'Regnārs', 'Regnolds', 'Rego', 'Reimārs', 'Reimo', 'Reinards', 'Reinārs', 'Reiners', 'Reinhards', 'Reinholds', 'Reinis', 'Reino', 'Reinolds', 'Reinvalds', 'Remberts', 'Remigijs', 'Remijs', 'Remirs', 'Remo', 'Rems', 'Renalds', 'Renards', 'Renārs', 'Renars', 'Renarts', 'Renato', 'Renāts', 'Renats', 'Rendijs', 'Renijs', 'Renno', 'Reno', 'Renolds', 'Rens', 'Reons', 'Rets', 'Revs', 'Ričards', 'Ričijs', 'Ričs', 'Rids', 'Rigo', 'Rigonds', 'Rihards', 'Riho', 'Rikardo', 'Rikijs', 'Riks', 'Rimands', 'Rimants', 'Rimars', 'Rimonds', 'Rimons', 'Rinaldo', 'Rinalds', 'Rinalts', 'Rinards', 'Rinārs', 'Rinats', 'Ringo', 'Ringolds', 'Rinolds', 'Rio', 'Rišars', 'Ritmars', 'Ritums', 'Ritvaldis', 'Ritvalds', 'Ritvars', 'Rivo', 'Rjuriks', 'Roalds', 'Roans', 'Robērs', 'Roberto', 'Roberts', 'Robijs', 'Robins', 'Rodijs', 'Rodions', 'Rodrigo', 'Rodžers', 'Rojs', 'Rokijs', 'Roko', 'Rolands', 'Rolāns', 'Rolfs', 'Rolijs', 'Romalds', 'Romands', 'Romāns', 'Romans', 'Romants', 'Romass', 'Romēns', 'Romeo', 'Romis', 'Roms', 'Romualds', 'Romulds', 'Romunds', 'Romuss', 'Romvalds', 'Ronaldo', 'Ronalds', 'Ronijs', 'Ronvalds', 'Rorijs', 'Rostams', 'Rostislavs', 'Rovens', 'Rubens', 'Rudiards', 'Rūdis', 'Rūdolfs', 'Rudolfs', 'Ruriks', 'Rūsiņš', 'Ruslands', 'Ruslāns', 'Rustams',
        'Saīds', 'Saigits', 'Saimons', 'Sairis', 'Saivis', 'Salamons', 'Salimons', 'Sallijs', 'Salomons', 'Salvijs', 'Salvis', 'Salvo', 'Samirs', 'Samsons', 'Samuels', 'Samuēls', 'Samvels', 'Sančo', 'Sandars', 'Sanders', 'Sandijs', 'Sandis', 'Sando', 'Sandors', 'Sandrino', 'Sandris', 'Sandro', 'Sandrs', 'Sandus', 'Sanduss', 'Sangvids', 'Sanijs', 'Santijs', 'Santis', 'Santo', 'Santoss', 'Sarmis', 'Saulceris', 'Saulgaitis', 'Saulis', 'Saulstars', 'Sauļus', 'Saulvedis', 'Savelijs', 'Sebastians', 'Sebastijans', 'Sebastjans', 'Sedriks', 'Seimanis', 'Seldzis', 'Selvijs', 'Selvīns', 'Selvis', 'Semions', 'Semjons', 'Sendijs', 'Sentis', 'Serafims', 'Sergejs', 'Sergo', 'Seržs', 'Severīns', 'Severins', 'Severjans', 'Sidars', 'Sidnejs', 'Sidors', 'Sigismunds', 'Sigits', 'Sigizmunds', 'Sigmārs', 'Sigmunds', 'Signijs', 'Signis', 'Sigords', 'Sigunds', 'Sigurds', 'Sigurts', 'Sigvards', 'Sigvars', 'Sigvarts', 'Silards', 'Silvars', 'Silvers', 'Silvesters', 'Silvestris', 'Silvestrs', 'Silvis', 'Sīmanis', 'Simeons', 'Simions', 'Simons', 'Sindijs', 'Singurs', 'Sintijs', 'Sirdsvaldis', 'Skaidris', 'Skaudris', 'Smaidonis', 'Smailis', 'Smuidris', 'Solomons', 'Solvis', 'Sondars', 'Sondris', 'Spartaks', 'Spēkonis', 'Spodris', 'Spricis', 'Staldzis', 'Staņislavs', 'Stanislavs', 'Stasis', 'Stass', 'Stefans', 'Stefāns', 'Steinārs', 'Stenlijs', 'Stepans', 'Stepons', 'Stīvens', 'Svenis', 'Svens', 'Svetoslavs', 'Svjatoslavs',
        'Šandors',
        'Tadeušs', 'Tagils', 'Tahirs', 'Taivo', 'Tālavs', 'Tālis', 'Tālivaldis', 'Tālivalds', 'Tālrids', 'Tālrīts', 'Tālrits', 'Tāls', 'Tālvaldis', 'Tamārs', 'Tarass', 'Taunis', 'Tautmīlis', 'Tautvaldis', 'Tautvaris', 'Tedijs', 'Tedis', 'Teldijs', 'Telesfors', 'Tenis', 'Teo', 'Teobalds', 'Teodors', 'Teofils', 'Teovils', 'Terijs', 'Tihons', 'Tils', 'Timofejs', 'Timotejs', 'Tims', 'Timurs', 'Tits', 'Tobijs', 'Toivo', 'Tomass', 'Tomašs', 'Tomijs', 'Toms', 'Tonijs', 'Toralfs', 'Torolfs', 'Tors', 'Torvalds', 'Treviss', 'Trofims', 'Tumašs', 'Turaids', 'Tūrs',
        'Udo', 'Uģis', 'Ugo', 'Ulams', 'Uldis', 'Uldriķis', 'Ulfs', 'Uljans', 'Uļjans', 'Ulrihs', 'Ulriks', 'Ulvars', 'Ulvis', 'Umberts', 'Undalgs', 'Undis', 'Ungars', 'Uno', 'Uvis',
        'Vaclavs', 'Vadims', 'Vagifs', 'Vahtangs', 'Vaidelotis', 'Vaidis', 'Vaino', 'Vairis', 'Vaironis', 'Vairons', 'Vaits', 'Vaivars', 'Valdeko', 'Valdeks', 'Valdemārs', 'Valdemars', 'Valdimārts', 'Valdimirs', 'Valdis', 'Valdmiers', 'Valdonis', 'Valdons', 'Valds', 'Valeks', 'Valentijs', 'Valentīns', 'Valentins', 'Valents', 'Valeriāns', 'Valerijāns', 'Valērijs', 'Valerijs', 'Valerjāns', 'Valfrīds', 'Valgudis', 'Valijs', 'Valteris', 'Valters', 'Valtīns', 'Valtis', 'Valts', 'Varaidotis', 'Varaidots', 'Varfolomejs', 'Varimands', 'Varimants', 'Varis', 'Varonis', 'Vasīlijs', 'Vasils', 'Večeslavs', 'Večislavs', 'Veidols', 'Veiko', 'Veimārs', 'Veino', 'Velards', 'Velerjans', 'Vello', 'Venancijs', 'Venantijs', 'Venceslavs', 'Venčeslavs', 'Vencislavs', 'Vendijs', 'Venedikts', 'Veners', 'Veno', 'Ventis', 'Vents', 'Verners', 'Vernis', 'Vernons', 'Veronis', 'Vestards', 'Vicents', 'Vidards', 'Vidars', 'Vidarts', 'Videvuds', 'Videvuts', 'Vidis', 'Vidmands', 'Vidmants', 'Vidmunds', 'Vido', 'Vidulis', 'Vidvars', 'Vidvedis', 'Vidvuds', 'Vidvuts', 'Viestards', 'Viestars', 'Viestarts', 'Viesturis', 'Viesturs', 'Vieturs', 'Vīgants', 'Vigars', 'Vigelijs', 'Vigilijs', 'Vīgo', 'Vigors', 'Vigorts', 'Vigurds', 'Vijārs', 'Vijtauts', 'Vikars', 'Vikentijs', 'Vikijs', 'Viktorijs', 'Viktors', 'Vilārs', 'Vilberts', 'Vilemons', 'Vilens', 'Vilfrīds', 'Vilhelmīns', 'Vilhelms', 'Vilibalds', 'Viliberts', 'Vilijs', 'Vīlips', 'Vilis', 'Viljams', 'Villems', 'Villijs', 'Vilmārs', 'Vilmars', 'Vilnis', 'Viļums', 'Viļus', 'Vinārs', 'Vincens', 'Vincentijs', 'Vincents', 'Vinceslavs', 'Vincs', 'Viners', 'Vinets', 'Vinifreds', 'Vinolds', 'Vinsents', 'Vintārs', 'Vints', 'Virgilijs', 'Virginijs', 'Viskants', 'Vismands', 'Vismants', 'Visvaldis', 'Visvalds', 'Visvaris', 'Visvars', 'Vitālijs', 'Vitalijs', 'Vitālis', 'Vitaliss', 'Vitāls', 'Vitars', 'Vitauts', 'Vītauts', 'Vitis', 'Vito', 'Vitolds', 'Vitols', 'Vitors', 'Vits', 'Vitus', 'Vivaldis', 'Vivanto', 'Vizbulis', 'Vizulis', 'Vjačeslavs', 'Vladeks', 'Vladilens', 'Vladimirs', 'Vladis', 'Vladislavs', 'Vladlens', 'Vlads', 'Vmcis', 'Voicehs', 'Voiceks', 'Voicihs', 'Voiciks', 'Voičiks', 'Voitiks', 'Voldemārs', 'Voldemars', 'Voldis', 'Voldmārs', 'Volfgangs', 'Volfreds', 'Volfrīds', 'Volfs', 'Volmārs', 'Vsevolods', 'Vudis', 'Vudro', 'Vulmārs',
        'Zaigonis', 'Zālamans', 'Zalamons', 'Zāmuels', 'Zandars', 'Zanders', 'Zandis', 'Zbigņevs', 'Zdeneks', 'Zelmars', 'Zemgus', 'Zemvaldis', 'Zemvalds', 'Zenons', 'Zezostris', 'Ziedonis', 'Ziedons', 'Zigfrīds', 'Zigfrids', 'Zigis', 'Zigismunds', 'Zigizmunds', 'Zigmans', 'Zigmants', 'Zigmāris', 'Zigmārs', 'Zigmars', 'Zigmonds', 'Zigmonts', 'Zigmunds', 'Zigmunts', 'Zigo', 'Zigonis', 'Zigrīds', 'Zigrids', 'Zigurds', 'Zigurts', 'Zigvards', 'Zilgars', 'Zinaidis', 'Zinaids', 'Zinovijs', 'Zintars', 'Zintauts', 'Zintis', 'Zinturs',
        'Žaks', 'Žanis', 'Žanno', 'Žano', 'Žans', 'Ženijs', 'Žerārs', 'Žoržs', 'Žozefs',
    ];

    /**
     * {@link} http://vardunozime.lv/names-female
     */
    protected static $firstNameFemale = [
        'Ada', 'Adala', 'Adalberta', 'Adela', 'Adelaida', 'Adelaide', 'Adele', 'Adelfina', 'Adelgunde', 'Adelheida', 'Adelheide', 'Adelija', 'Adēlija', 'Adelīna', 'Adelina', 'Adija', 'Adīna', 'Adīne', 'Adonija', 'Adriāna', 'Adrija', 'Aelita', 'Afanasija', 'Afra', 'Afrodīte', 'Agafija', 'Agata', 'Agate', 'Agāte', 'Agija', 'Agika', 'Agita', 'Aglikerija', 'Agna', 'Agnda', 'Agne', 'Agnesa', 'Agnese', 'Agnesija', 'Agneška', 'Agņeška', 'Agneta', 'Agnete', 'Agneze', 'Agnēze', 'Agnija', 'Agnita', 'Agra', 'Agreda', 'Agrida', 'Agrija', 'Agrina', 'Agripina', 'Agrita', 'Agrīte', 'Agunda', 'Aīda', 'Aida', 'Aiga', 'Aigija', 'Aigita', 'Aigula', 'Aija', 'Aila', 'Ailenda', 'Aili', 'Ailija', 'Ailita', 'Aina', 'Aināra', 'Ainita', 'Aira', 'Airida', 'Airika', 'Airīna', 'Airisa', 'Airita', 'Airite', 'Aisma', 'Aista', 'Aiva', 'Aivija', 'Aivika', 'Aivita', 'Ajita', 'Akilina', 'Aksenija', 'Akulina', 'Akuļina', 'Akvelīna', 'Akvelina', 'Akvilīna', 'Ala', 'Alaida', 'Alba', 'Alberta', 'Albertīna', 'Albertīne', 'Albertine', 'Albīna', 'Albina', 'Albīne', 'Alda', 'Aldija', 'Aldīna', 'Aldona', 'Aldone', 'Aldonija', 'Aldra', 'Aleftīna', 'Aleftine', 'Aleksa', 'Aleksandra', 'Aleksandrīna', 'Aleksandrine', 'Alena', 'Alēna', 'Alerina', 'Alesja', 'Aleta', 'Alevtīna', 'Alevtīne', 'Alfa', 'Alfija', 'Alfonija', 'Alfra', 'Alfrīda', 'Ali', 'Alīcija', 'Alīda', 'Alida', 'Alīde', 'Alīdija', 'Alija', 'Alika', 'Alimpiada', 'Alīna', 'Alina', 'Aļina', 'Alīne', 'Alīsa', 'Alise', 'Alīse', 'Alīsija', 'Alita', 'Alla', 'Allija', 'Alma', 'Almāra', 'Alna', 'Alodija', 'Aloīda', 'Aloiza', 'Aloizija', 'Aļona', 'Alondra', 'Alta', 'Alva', 'Alvija', 'Alvika', 'Alvīna', 'Alvīne', 'Alvine', 'Alvinija', 'Alvita', 'Alžbeta', 'Amalda', 'Amālija', 'Amanda', 'Amanta', 'Amantija', 'Amaranda', 'Amaranta', 'Amarilla', 'Amelija', 'Amēlija', 'Amelita', 'Amenta', 'Amīda', 'Amilda', 'Ammonārija', 'Amrita', 'Ana', 'Aņa', 'Anabella', 'Anaita', 'Anāra', 'Anastasija', 'Anastāsija', 'Anastāzija', 'Anata', 'Anatolija', 'Ance', 'Anda', 'Andija', 'Andīna', 'Andina', 'Andīne', 'Andra', 'Andre', 'Andrelita', 'Andreta', 'Andriāna', 'Andrija', 'Andrijana', 'Andrika', 'Andrita', 'Andromeda', 'Andžela', 'Andželika', 'Andželīna', 'Andželita', 'Andžella', 'Ane', 'Aneka', 'Aņela', 'Aneļa', 'Anēla', 'Anela', 'Anēle', 'Anēlija', 'Anelija', 'Anemarija', 'Anese', 'Aneta', 'Anete', 'Anfija', 'Anfisa', 'Anga', 'Angeļa', 'Angela', 'Angelija', 'Angelika', 'Angēlika', 'Angelīna', 'Angelita', 'Anhelita', 'Aniceta', 'Anija', 'Anika', 'Anisija', 'Aņisija', 'Aņisja', 'Anita', 'Anitra', 'Ankatrina', 'Anlīza', 'Anlīze', 'Anlizeta', 'Anmāra', 'Anmarija', 'Anna', 'Annamarija', 'Anne', 'Annele', 'Annelija', 'Annemarija', 'Anneta', 'Annete', 'Annija', 'Annika', 'Anniņa', 'Anrita', 'Anta', 'Antainna', 'Antija', 'Antonela', 'Antonīda', 'Antonija', 'Antoņina', 'Antonīna', 'Antra', 'Antuaneta', 'Antuanete', 'Aņuta', 'Anžela', 'Anželika', 'Anželina', 'Anželita', 'Anžella', 'Anzelma', 'Apolinārija', 'Apolonija', 'Aralda', 'Aranta', 'Areta', 'Arfa', 'Argija', 'Argita', 'Argunda', 'Ariadna', 'Ariadne', 'Ariāna', 'Arianda', 'Ariandra', 'Arianna', 'Arīda', 'Arieta', 'Arija', 'Arimanda', 'Arīna', 'Arisa', 'Aristīda', 'Arita', 'Arjana', 'Arkādija', 'Arlita', 'Arma', 'Armanda', 'Armīda', 'Armilda', 'Arne', 'Arnīda', 'Arnija', 'Arnika', 'Arnita', 'Arta', 'Artemida', 'Artija', 'Arvaldina', 'Arvīda', 'Arvīde', 'Arvita', 'Asija', 'Asja', 'Asma', 'Asna', 'Asnate', 'Asnāte', 'Asne', 'Asola', 'Aspāzija', 'Asterija', 'Astērija', 'Astra', 'Astrīda', 'Astrida', 'Astrīde', 'Astrīte', 'Asunta', 'Ata', 'Atala', 'Atēna', 'Auce', 'Auda', 'Augenija', 'Augusta', 'Auguste', 'Augustīna', 'Augustīne', 'Aura', 'Aurēlija', 'Aurelija', 'Aurika', 'Aurora', 'Ausma', 'Aušra', 'Aušra', 'Austra', 'Austrīte', 'Avelīna', 'Avija', 'Avita', 'Aviva', 'Azanda', 'Azella',
        'Ādolfina', 'Ādolfīne', 'Āra', 'Ārija', 'Ārika', 'Ārite', 'Ārvalda',
        'Baiba', 'Balva', 'Banga', 'Baņuta', 'Barba', 'Bārbala', 'Barbala', 'Barbara', 'Barbola', 'Bažena', 'Beāta', 'Beāte', 'Beate', 'Beatrisa', 'Beatrise', 'Bekija', 'Belinda', 'Bella', 'Bemadita', 'Benedikta', 'Beneventa', 'Benigna', 'Benija', 'Benilda', 'Benita', 'Benjamina', 'Benoventa', 'Berenika', 'Berita', 'Bernada', 'Bernāde', 'Bernadeta', 'Bernadete', 'Bernadina', 'Bernadīne', 'Bernadīte', 'Bernarda', 'Bernarde', 'Bernardīna', 'Bernedīne', 'Berta', 'Beruta', 'Beta', 'Betija', 'Betsija', 'Bianka', 'Bille', 'Biminita', 'Binija', 'Binnija', 'Birgita', 'Biruta', 'Birute', 'Bitīte', 'Blāzma', 'Bogumila', 'Boļeslava', 'Bonaventūra', 'Bonifācija', 'Bonija', 'Bonoventura', 'Borbala', 'Borbola', 'Borbula', 'Borghilde', 'Božena', 'Brenda', 'Breta', 'Briāna', 'Bridžita', 'Brigita', 'Brina', 'Brinda', 'Brita', 'Brīva', 'Brīve', 'Brīvīte', 'Broņa', 'Bronhilda', 'Bronija', 'Broņislava', 'Bronislava', 'Brunhilda', 'Brunhilde', 'Brunita',
        'Čarita', 'Čelsija', 'Čereta', 'Česlava', 'Čezeta',
        'Cecīlija', 'Cecilija', 'Celerīna', 'Celīna', 'Centa', 'Centolla', 'Cera', 'Cerība', 'Cezarija', 'Cicilija', 'Ciedra', 'Cilda', 'Cilija', 'Cilina', 'Cilmija', 'Cilnija', 'Cina', 'Cintija', 'Cirēnija',
        'Dace', 'Dacija', 'Dacīte', 'Daglta', 'Dagmāra', 'Dagmara', 'Dagna', 'Dagne', 'Dagnija', 'Dagnita', 'Daidze', 'Daiga', 'Daigone', 'Daija', 'Daila', 'Daile', 'Daimona', 'Daina', 'Dainavīte', 'Dainida', 'Dainita', 'Dainīte', 'Dainuvīte', 'Daira', 'Dairita', 'Daiva', 'Dajana', 'Dālija', 'Dana', 'Dane', 'Daneta', 'Danica', 'Danida', 'Daniela', 'Dāniela', 'Daniēla', 'Daniella', 'Danija', 'Danika', 'Daņila', 'Danita', 'Danna', 'Danuta', 'Daņuta', 'Danute', 'Dārija', 'Darina', 'Darja', 'Dārta', 'Dārte', 'Debora', 'Dedze', 'Deina', 'Deivija', 'Deizija', 'Delfīna', 'Delfīne', 'Demija', 'Denija', 'Denisa', 'Denise', 'Denīza', 'Denīze', 'Denora', 'Dēvija', 'Dezija', 'Dēzija', 'Diāna', 'Diana', 'Diandra', 'Dianna', 'Diāra', 'Dida', 'Digna', 'Digne', 'Dina', 'Dīna', 'Dināra', 'Dineta', 'Dinija', 'Dinnija', 'Dita', 'Dite', 'Dolita', 'Dollija', 'Doloresa', 'Dome', 'Domenika', 'Domicela', 'Domicele', 'Domicelija', 'Domicella', 'Domija', 'Dominika', 'Domna', 'Domuse', 'Donāta', 'Donāte', 'Donicela', 'Donvina', 'Dora', 'Dore', 'Doreta', 'Dorina', 'Dorisa', 'Dorita', 'Dorota', 'Doroteja', 'Dorotija', 'Dorta', 'Dorte', 'Drosma', 'Drosme', 'Dūda', 'Džamila', 'Džana', 'Džaneta', 'Džanete', 'Džanita', 'Džasmīna', 'Džastina', 'Džeina', 'Dzeja', 'Dzelde', 'Džellija', 'Dzelme', 'Džema', 'Džemma', 'Džena', 'Dženeta', 'Dženete', 'Dženifera', 'Dženija', 'Dženita', 'Džeralda', 'Džeraldīne', 'Džesija', 'Džesika', 'Dzestra', 'Dzidra', 'Dzidrite', 'Dziedra', 'Dziesma', 'Džigunda', 'Džilda', 'Dzīle', 'Džina', 'Dzine', 'Džineta', 'Džinita', 'Dzinta', 'Dzintara', 'Dzintāra', 'Dzintārija', 'Dzintra', 'Dzirkstīte', 'Džoanna', 'Džoija', 'Džoja', 'Džovita', 'Džudīte', 'Džūlija', 'Džuljeta',
        'Eba', 'Eda', 'Ede', 'Edija', 'Edīta', 'Edīte', 'Edite', 'Edla', 'Edmonda', 'Edna', 'Eduarda', 'Edviga', 'Edvija', 'Edvīna', 'Edvīne', 'Efeja', 'Ega', 'Egida', 'Egija', 'Egīna', 'Egita', 'Egle', 'Egmonta', 'Eifrozine', 'Eila', 'Eina', 'Eiženija', 'Eižēnija', 'Eļa', 'Elāna', 'Elda', 'Elektra', 'Elena', 'Elēna', 'Elenora', 'Eleonora', 'Elfa', 'Elfija', 'Elfrīda', 'Elfrida', 'Elfrīde', 'Elga', 'Elgita', 'Elīda', 'Elija', 'Elika', 'Elīna', 'Elina', 'Elīne', 'Elionora', 'Elīsa', 'Elise', 'Elita', 'Elite', 'Elīza', 'Eliza', 'Elīzabeta', 'Elizabete', 'Elīzabete', 'Elizaveta', 'Elizavete', 'Elizbete', 'Elize', 'Ella', 'Ellana', 'Ellena', 'Ellija', 'Elma', 'Elmāra', 'Elmija', 'Elmīna', 'Elmīne', 'Elmīra', 'Elmira', 'Elna', 'Elnāra', 'Elneta', 'Elona', 'Elta', 'Elva', 'Elvi', 'Elviga', 'Elvija', 'Elvīna', 'Elvīne', 'Elvīra', 'Elvira', 'Elvisa', 'Elvita', 'Elza', 'Elzabeta', 'Elžbeta', 'Ema', 'Emanuēla', 'Emarita', 'Emerenciana', 'Emerencija', 'Emerencijana', 'Emerenta', 'Emerentiana', 'Emerentina', 'Emerentīne', 'Emerita', 'Emertijana', 'Emija', 'Emilda', 'Emiliana', 'Emīlija', 'Emilija', 'Emilijana', 'Emīlja', 'Emiljana', 'Emīra', 'Emirita', 'Emma', 'Emme', 'Ena', 'Enda', 'Endija', 'Endžija', 'Ene', 'Enerita', 'Engelīna', 'Enīda', 'Enija', 'Enina', 'Enita', 'Ennata', 'Ennija', 'Enrija', 'Enrika', 'Enriketa', 'Enta', 'Envija', 'Era', 'Erena', 'Erēna', 'Eridana', 'Erika', 'Erīna', 'Erita', 'Erma', 'Ermīna', 'Ermīne', 'Ermionija', 'Ermonija', 'Erna', 'Erneste', 'Ernestīna', 'Ernestīne', 'Ernestine', 'Ernita', 'Ervīna', 'Ervita', 'Esēnija', 'Esfira', 'Esija', 'Esmeralda', 'Esmeralde', 'Estella', 'Estera', 'Estere', 'Estra', 'Eta', 'Etele', 'Etelvīne', 'Etere', 'Eteri', 'Etīna', 'Euģenija', 'Euģēnija', 'Eugenija', 'Eugēnija', 'Eulālija', 'Eva', 'Evalina', 'Eve', 'Evelīna', 'Evelina', 'Evelīne', 'Evelita', 'Everika', 'Everita', 'Evgēnija', 'Evgenija', 'Evģēnija', 'Evģenija', 'Evī', 'Evija', 'Evika', 'Evisa', 'Evita', 'Evrika',
        'Ēra', 'Ērika', 'Ēstere', 'Ēva', 'Ēvī', 'Ēvija', 'Ēvisa',
        'Faina', 'Fanija', 'Fannija', 'Farida', 'Fatima', 'Fatina', 'Fatma', 'Feja', 'Feliciāna', 'Felicianna', 'Felīcija', 'Felicijana', 'Felicita', 'Felicjana', 'Felonija', 'Fenija', 'Feodora', 'Feodosija', 'Feona', 'Feonija', 'Fetna', 'Fevronija', 'Filemona', 'Filgita', 'Filicija', 'Filimona', 'Fiļimona', 'Filimonija', 'Filiomena', 'Filipina', 'Filomeja', 'Filomena', 'Filumena', 'Fionija', 'Flora', 'Florence', 'Florentija', 'Florentīna', 'Florentīne', 'Floriana', 'Florija', 'Florijana', 'Fortunata', 'Frančeska', 'Franciska', 'Franciška', 'Frančiska', 'Fransuāza', 'Františka', 'Franuse', 'Fraskita', 'Frederika', 'Frensisa', 'Frīda', 'Frida', 'Friderika', 'Fridriha',
        'Gabija', 'Gabriēla', 'Gabriela', 'Gabriele', 'Gabriella', 'Gaida', 'Gaidite', 'Gaija', 'Gaisma', 'Gaismīte', 'Gaismone', 'Gaita', 'Galina', 'Gaļina', 'Ganda', 'Geda', 'Gēda', 'Gedra', 'Geila', 'Gelija', 'Gēlija', 'Gelinta', 'Genefa', 'Generoza', 'Genija', 'Genita', 'Genovaite', 'Genovefa', 'Genoveja', 'Genovera', 'Genoveva', 'Gentra', 'Genuvefa', 'Geraldina', 'Gerarda', 'Gerda', 'Geronima', 'Gertija', 'Gertrūda', 'Gertrūde', 'Gertrude', 'Gesta', 'Gianeja', 'Giedra', 'Gija', 'Gina', 'Gināra', 'Gineta', 'Ginita', 'Ginta', 'Gintija', 'Gita', 'Gitāna', 'Gitija', 'Gizela', 'Glafīra', 'Glaima', 'Glauda', 'Gledisa', 'Glenda', 'Glendija', 'Glikerija', 'Glita', 'Glorija', 'Gonda', 'Gotlība', 'Grācija', 'Grasilda', 'Grata', 'Gražina', 'Greta', 'Grēta', 'Grieta', 'Grietina', 'Grineta', 'Grinete', 'Grita', 'Grizelda', 'Gudrīte', 'Gudruna', 'Gulnara', 'Guļnara', 'Guna', 'Gunāra', 'Gunavefa', 'Gunda', 'Gundega', 'Gundija', 'Gundra', 'Gunefa', 'Guneta', 'Gunita', 'Gunitra', 'Gunmāra', 'Gunta', 'Guntiņa', 'Guntra', 'Gusta', 'Guste', 'Gvenda', 'Gvida', 'Gvidālija',
        'Ģēda', 'Ģenovefa', 'Ģertcuda', 'Ģertrūda', 'Ģertrūde', 'Ģertrude', 'Ģiedra', 'Ģinta',
        'Haida', 'Haide', 'Halina', 'Halīna', 'Hanelita', 'Hanna', 'Hannelore', 'Hannija', 'Hanzija', 'Haralda', 'Hardija', 'Harija', 'Harina', 'Harita', 'Haritina', 'Heda', 'Hedija', 'Hedviga', 'Heidija', 'Helēna', 'Helena', 'Helēne', 'Helene', 'Helga', 'Helge', 'Helgi', 'Helgrīda', 'Hēlija', 'Helita', 'Helju', 'Hella', 'Hellēna', 'Hellija', 'Helma', 'Helmija', 'Helmīna', 'Helmīne', 'Helmīra', 'Helmute', 'Helta', 'Helvi', 'Helvija', 'Helvita', 'Henija', 'Henisa', 'Henita', 'Hennija', 'Henrieta', 'Henriete', 'Henrija', 'Henrika', 'Henrita', 'Hēra', 'Hera', 'Herenija', 'Herita', 'Herma', 'Hermīna', 'Hermīne', 'Hermine', 'Heronija', 'Heronima', 'Herta', 'Hervita', 'Hetija', 'Hiacinta', 'Hilarija', 'Hilda', 'Hildegarde', 'Hildura', 'Hilga', 'Hilja', 'Hilma', 'Honorata', 'Honoreta', 'Hortenzija', 'Hulda',
        'Ida', 'Ideja', 'Idilija', 'Idra', 'Ieva', 'Ieviņa', 'Igeta', 'Igila', 'Igita', 'Ignese', 'Igunda', 'Ija', 'Ilāna', 'Ilanda', 'Ilanta', 'Ilāra', 'Ilārija', 'Ilda', 'Ildra', 'Ildze', 'Ileana', 'Ilga', 'Ilgnese', 'Ilgona', 'Iliana', 'Ilija', 'Ilita', 'Ilizana', 'Ilizane', 'Iļja', 'Iljana', 'Iļjana', 'Illa', 'Illarija', 'Illuminata', 'Ilma', 'Ilmara', 'Ilme', 'Ilmija', 'Ilna', 'Ilona', 'Ilonda', 'Ilone', 'Ilonija', 'Iluta', 'Ilva', 'Ilveta', 'Ilvija', 'Ilvīra', 'Ilvita', 'Ilza', 'Ilze', 'Ilzīte', 'Ima', 'Imalda', 'Imanda', 'Imandra', 'Imanta', 'Imelda', 'Imgarde', 'Imre', 'Imula', 'Ina', 'Inaida', 'Ināra', 'Inara', 'Inārija', 'Inarta', 'Inatra', 'Inda', 'Indīra', 'Indra', 'Inelda', 'Inesa', 'Inese', 'Inesīte', 'Ineta', 'Inete', 'Inga', 'Inge', 'Ingeborga', 'Ingemāra', 'Ingera', 'Ingēra', 'Ingerūda', 'Ingeta', 'Ingita', 'Ingmāra', 'Ingra', 'Ingre', 'Ingreta', 'Ingrīda', 'Ingrida', 'Ingrita', 'Inguna', 'Ingūna', 'Ingunda', 'Ingūra', 'Inguta', 'Ingvilda', 'Inija', 'Inita', 'Initra', 'Inna', 'Innara', 'Inneta', 'Inota', 'Inta', 'Intra', 'Inuta', 'Inveiga', 'Ira', 'Iraīda', 'Iraida', 'Iraisa', 'Irbe', 'Irēna', 'Irena', 'Irene', 'Irēne', 'Irīda', 'Irida', 'Irija', 'Irina', 'Irīna', 'Irisa', 'Irita', 'Irma', 'Irme', 'Irmgarda', 'Irmgarde', 'Irmiņa', 'Irmīna', 'Irmīne', 'Irmtrauta', 'Irmtraute', 'Irta', 'Iruta', 'Irute', 'Irvita', 'Irži', 'Isma', 'Ita', 'Itija', 'Iva', 'Ivaise', 'Ivanda', 'Ivande', 'Ivanna', 'Ivāra', 'Ivase', 'Ivena', 'Iverta', 'Iveta', 'Ivete', 'Ivika', 'Ivita', 'Ivona', 'Ivonda', 'Ivonija', 'Ivonna', 'Iza', 'Izabela', 'Izabella', 'Izanda', 'Izaura', 'Izīda', 'Izolda', 'Izolde',
        'Īda', 'Īģe', 'Īna', 'Īra', 'Īrisa', 'Īva', 'Īvija',
        'Jacinta', 'Jadviga', 'Jadvīga', 'Jadze', 'Jakobīna', 'Jalanta', 'Jana', 'Jāna', 'Janeka', 'Janeta', 'Janete', 'Janika', 'Janīna', 'Janina', 'Jaņīna', 'Janita', 'Janna', 'Janta', 'Januārija', 'Jaroslava', 'Jasmīna', 'Jasmīne', 'Jausma', 'Jautra', 'Jautrīte', 'Jāzepa', 'Jazepata', 'Jazupata', 'Jedviga', 'Jefimija', 'Jefrosīnija', 'Jekaterīna', 'Jeļena', 'Jeļizabeta', 'Jelizabeta', 'Jelizaveta', 'Jeļizaveta', 'Jelizavete', 'Jeļizavete', 'Jella', 'Jesija', 'Jeta', 'Jete', 'Jevdokija', 'Jevgēņija', 'Jevģenija', 'Jevģēnija', 'Jevgēnija', 'Jevgenija', 'Jevgeņija', 'Jevlampija', 'Jevženija', 'Jevžēnija', 'Jezufata', 'Jezupata', 'Jezupate', 'Joana', 'Joanna', 'Jogita', 'Johana', 'Johanna', 'Jolanda', 'Jolanta', 'Jolita', 'Jonita', 'Jovita', 'Jozefa', 'Jozefata', 'Jozefīna', 'Jozefīne', 'Juanna', 'Judīte', 'Jugita', 'Jūla', 'Jūle', 'Jūliāna', 'Jūļiana', 'Julianija', 'Jūlianna', 'Jūlija', 'Julija', 'Jūlijana', 'Julijanna', 'Julita', 'Juļjana', 'Juna', 'Jūnija', 'Junita', 'Junna', 'Junona', 'Junora', 'Junta', 'Juranta', 'Jūrāte', 'Jureta', 'Jurgita', 'Jurika', 'Jurita', 'Jūsma', 'Justa', 'Justīna', 'Justīne', 'Justine', 'Justīnija', 'Juta', 'Juvita', 'Juzefa', 'Juzefata', 'Juzefate', 'Juzefīna', 'Juzefine', 'Juzepa', 'Juzepata', 'Juzepate', 'Juzufata',
        'Kadrija', 'Kaija', 'Kaira', 'Kaiva', 'Kamēlija', 'Kamena', 'Kamila', 'Kamīlija', 'Kamilla', 'Kamita', 'Kandida', 'Karalina', 'Karena', 'Kārija', 'Karīna', 'Kārina', 'Karinē', 'Karīne', 'Karita', 'Karla', 'Karlīna', 'Karlina', 'Karlīne', 'Karmena', 'Karmene', 'Karola', 'Karolīna', 'Karolīne', 'Karulina', 'Kasandra', 'Katalīna', 'Katarīna', 'Katažina', 'Kate', 'Katerīna', 'Katija', 'Katiņa', 'Katra', 'Katre', 'Katri', 'Katrīna', 'Katrina', 'Katrīne', 'Katriona', 'Kazimerina', 'Kazimira', 'Kazimirina', 'Kazmerina', 'Kazmirina', 'Kecija', 'Keisija', 'Keita', 'Keitija', 'Kelija', 'Kellija', 'Kendija', 'Kerija', 'Kerola', 'Kerolaina', 'Kerolaine', 'Kersti', 'Kerstina', 'Keta', 'Kēta', 'Kete', 'Kēte', 'Ketija', 'Ketlīna', 'Ketrija', 'Ketrīna', 'Kilikeja', 'Kima', 'Kimberiija', 'Kintija', 'Kira', 'Kitija', 'Klāra', 'Klara', 'Klaudija', 'Klavdija', 'Klementīna', 'Klementīne', 'Klementine', 'Kleofa', 'Kleopatra', 'Kleotilda', 'Klēra', 'Klimentīna', 'Klinta', 'Klitija', 'Klodija', 'Klotilde', 'Koleta', 'Konkordija', 'Konstance', 'Konstancija', 'Konstantija', 'Konstantīna', 'Konstantīne', 'Konsuela', 'Konsuella', 'Kora', 'Korina', 'Kornēlija', 'Kornelija', 'Krista', 'Kriste', 'Kristela', 'Kristena', 'Kristiāna', 'Kristiana', 'Kristiāne', 'Kristianna', 'Kristija', 'Kristijana', 'Kristilla', 'Kristīna', 'Kristīne', 'Kristine', 'Ksaverija', 'Ksavērija', 'Ksenija', 'Ksēnija', 'Kunegunda', 'Kunigunda', 'Kuzma',
        'Ķērsta', 'Ķersta',
        'Lada', 'Laija', 'Laila', 'Lailita', 'Laima', 'Laimdota', 'Laimiņa', 'Laimīte', 'Laimrita', 'Laimrota', 'Laimute', 'Laina', 'Laine', 'Laineta', 'Laira', 'Laisve', 'Lala', 'Lalita', 'Lana', 'Lāna', 'Landa', 'Langina', 'Largija', 'Larija', 'Larina', 'Larisa', 'Lāse', 'Lāsma', 'Lasma', 'Lāsmiņa', 'Late', 'Latvīte', 'Lauma', 'Laumīte', 'Laura', 'Laure', 'Laurentīna', 'Laureta', 'Laurita', 'Lavīze', 'Lea', 'Leāna', 'Leāra', 'Leida', 'Leila', 'Leina', 'Lelda', 'Lelde', 'Lena', 'Lēna', 'Lendija', 'Lengina', 'Lenija', 'Lenita', 'Lenora', 'Lenvija', 'Leokādija', 'Leokadija', 'Leolita', 'Leona', 'Leonāra', 'Leonarda', 'Leonārija', 'Leone', 'Leongīna', 'Leongīne', 'Leonīda', 'Leonida', 'Leonide', 'Leonija', 'Leonila', 'Leonilla', 'Leonita', 'Leonora', 'Leonorija', 'Leontija', 'Leontīna', 'Leontīne', 'Leontine', 'Leopoldina', 'Letīcija', 'Levantīna', 'Levita', 'Lia', 'Liāna', 'Liana', 'Lianda', 'Lianta', 'Liāra', 'Lība', 'Liberata', 'Lida', 'Līda', 'Lidija', 'Lidita', 'Liega', 'Liena', 'Liene', 'Lienīte', 'Liesma', 'Līga', 'Ligija', 'Ligindra', 'Ligita', 'Lija', 'Līksma', 'Lilana', 'Lili', 'Liliāna', 'Liliana', 'Lilianna', 'Lilija', 'Līlija', 'Lilijana', 'Lilioza', 'Lilita', 'Lilja', 'Liljana', 'Lilli', 'Lillija', 'Lillita', 'Līna', 'Lina', 'Linarda', 'Linda', 'Linde', 'Lindija', 'Līne', 'Lineta', 'Linita', 'Linna', 'Liona', 'Lioneta', 'Lionija', 'Lipija', 'Lira', 'Līrija', 'Lisa', 'Lisija', 'Lita', 'Līva', 'Liva', 'Liveta', 'Līvija', 'Livija', 'Livita', 'Liza', 'Līza', 'Lizabete', 'Lizbete', 'Līze', 'Lize', 'Lizelote', 'Lizeta', 'Lizete', 'Līzete', 'Līziņa', 'Logina', 'Logita', 'Loida', 'Lola', 'Lolija', 'Lolita', 'Lollija', 'Lone', 'Longīna', 'Lonija', 'Lonita', 'Lonnija', 'Lontīne', 'Lora', 'Loransa', 'Loreina', 'Lorena', 'Lorēna', 'Lorensa', 'Lorenta', 'Loreta', 'Lorete', 'Lorija', 'Lorika', 'Lorina', 'Lorita', 'Lota', 'Lote', 'Loveta', 'Luāna', 'Lucianna', 'Lūcija', 'Lucija', 'Lucijana', 'Ludmila', 'Ludmilla', 'Ludovika', 'Ludviga', 'Ludvika', 'Ludvisa', 'Ludvise', 'Ludvisija', 'Lueta', 'Lugra', 'Luīza', 'Luīze', 'Luize', 'Lukrecija', 'Lukrēcija', 'Lūlija', 'Lusija', 'Lusja',
        'Ļoņa', 'Ļubova', 'Ļudgarda', 'Ļudvise',
        'Madaļa', 'Madara', 'Madare', 'Made', 'Madelaina', 'Madlena', 'Madlēna', 'Mafalda', 'Magda', 'Magdalēna', 'Magdalena', 'Magdaliene', 'Magdalina', 'Magnolija', 'Magone', 'Magrieta', 'Magrita', 'Maida', 'Maiga', 'Maigone', 'Maija', 'Maila', 'Maima', 'Maina', 'Maira', 'Mairina', 'Mairita', 'Mairite', 'Mairuta', 'Makrina', 'Malānija', 'Malda', 'Maldiņa', 'Māle', 'Malgonija', 'Malgožata', 'Malle', 'Malva', 'Malvīna', 'Malvīne', 'Malvine', 'Manda', 'Manefa', 'Manuela', 'Māra', 'Maranda', 'Maranta', 'Marcela', 'Marčela', 'Marcelina', 'Marcella', 'Marciana', 'Marcianna', 'Marčija', 'Marcijana', 'Marcijanna', 'Māre', 'Mareka', 'Māreta', 'Marfa', 'Marga', 'Margareta', 'Margarēta', 'Margarieta', 'Margarita', 'Mārģieta', 'Margieta', 'Margita', 'Margnta', 'Margota', 'Margote', 'Margreta', 'Margrieta', 'Marguta', 'Marī', 'Mariana', 'Marianna', 'Mārica', 'Mariela', 'Mārieta', 'Marija', 'Marijana', 'Marijanna', 'Marijeta', 'Marika', 'Mārika', 'Marina', 'Marīna', 'Mariona', 'Marisa', 'Marita', 'Mārita', 'Maritana', 'Mārīte', 'Marīte', 'Marjama', 'Marjana', 'Marjanna', 'Marjeta', 'Marlēna', 'Marlena', 'Marsela', 'Marseljēza', 'Marsella', 'Marta', 'Mārta', 'Martijana', 'Martīna', 'Maruta', 'Māruta', 'Marute', 'Matilda', 'Matilde', 'Matrjona', 'Matrona', 'Mazalda', 'Mečislava', 'Medeja', 'Mega', 'Megija', 'Mehribana', 'Melānija', 'Melanija', 'Meldra', 'Melija', 'Melinda', 'Melisa', 'Melisandra', 'Melita', 'Melitina', 'Melizanda', 'Melizande', 'Menarda', 'Mendija', 'Meralda', 'Meri', 'Merīda', 'Mērija', 'Merija', 'Merilina', 'Merita', 'Merseda', 'Mersēda', 'Mersedesa', 'Meta', 'Mēta', 'Mētra', 'Mīce', 'Midite', 'Miervalda', 'Mihailina', 'Mihaļina', 'Mihalīna', 'Mija', 'Mikaela', 'Mikalina', 'Mīla', 'Milāna', 'Milda', 'Mildreda', 'Mīle', 'Milēna', 'Milena', 'Milica', 'Milija', 'Milita', 'Millija', 'Milona', 'Milvija', 'Mimoza', 'Mina', 'Minadora', 'Mindora', 'Minjona', 'Minna', 'Mira', 'Mirabella', 'Miralda', 'Miranda', 'Mirdza', 'Mirga', 'Mirjāma', 'Mirjana', 'Miroslava', 'Mirta', 'Mišela', 'Moda', 'Modesta', 'Modra', 'Modrīte', 'Molija', 'Mollija', 'Mona', 'Monda', 'Monija', 'Monika', 'Monna', 'Monrita', 'Monta', 'Monvida', 'Mora', 'Morēna', 'Mudīte', 'Mudra', 'Mudrīte', 'Munda', 'Mundra', 'Mundrīte', 'Munise', 'Mūza',
        'Nadežda', 'Nadija', 'Nadīna', 'Nadina', 'Nadīne', 'Naila', 'Naina', 'Naira', 'Nameda', 'Nana', 'Nanda', 'Nanete', 'Nanija', 'Nannija', 'Nansija', 'Naomi', 'Nāra', 'Narcise', 'Narciza', 'Nargisa', 'Nargiza', 'Nārija', 'Narine', 'Nastasija', 'Nastja', 'Nata', 'Natalī', 'Natālija', 'Natalija', 'Nataļja', 'Natalja', 'Nate', 'Natela', 'Natella', 'Naula', 'Necija', 'Neda', 'Neila', 'Neļa', 'Nelda', 'Nelija', 'Nelima', 'Nelita', 'Nella', 'Nellija', 'Nena', 'Nensija', 'Neonila', 'Neonilla', 'Nērika', 'Neringa', 'Neta', 'Niāra', 'Niceta', 'Nida', 'Nigra', 'Nija', 'Nijole', 'Nika', 'Nikija', 'Nikita', 'Nikola', 'Nikoleta', 'Nila', 'Nilda', 'Nilija', 'Niluta', 'Nimmija', 'Nīna', 'Ninele', 'Ninella', 'Nineta', 'Ninona', 'Niola', 'Nīra', 'Nita', 'Noela', 'Nominanda', 'Nona', 'Nonna', 'Nora', 'Norgita', 'Norika', 'Noriņa', 'Norīte', 'Norma', 'Normanta', 'Normunda', 'Norvalda',
        'Ņina', 'Ņīna',
        'Odeta', 'Odita', 'Odrija', 'Ofēlija', 'Oksana', 'Oksāna', 'Oktāvija', 'Olesija', 'Oļesija', 'Olesja', 'Oļesja', 'Olga', 'Olgita', 'Olija', 'Olimpiada', 'Olimpija', 'Olina', 'Olita', 'Olīva', 'Olīvija', 'Olivija', 'Ollija', 'Olrita', 'Olvija', 'Olvita', 'Omula', 'Ona', 'Oneta', 'Oniksa', 'Onufrija', 'Orhideja', 'Orīda', 'Ornella', 'Ortenzija', 'Ortija', 'Oskarīna', 'Otālija', 'Otīlija', 'Otilija',
        'Paija', 'Palmīra', 'Pamela', 'Pārsla', 'Pārsliņa', 'Patrīcija', 'Patricija', 'Paula', 'Pauleta', 'Paulīna', 'Paulīne', 'Pauline', 'Pavlīna', 'Pavlīne', 'Pegija', 'Pelageja', 'Pērie', 'Petra', 'Petronela', 'Petronele', 'Petronelija', 'Petronella', 'Petronellija', 'Petrunela', 'Petruneļa', 'Petrunele', 'Petrunelija', 'Pilimona', 'Pireta', 'Polīna', 'Poļina', 'Potencija', 'Praskovja', 'Proskovja', 'Pudencija', 'Pudentija',
        'Rada', 'Radmila', 'Radu', 'Raēle', 'Ragnēda', 'Ragnija', 'Raida', 'Raiena', 'Raija', 'Raima', 'Raimija', 'Raimona', 'Raimonda', 'Raina', 'Rainelda', 'Rainelde', 'Raisa', 'Raisma', 'Raita', 'Raiva', 'Raivita', 'Raja', 'Raksana', 'Ralda', 'Ramīna', 'Ramona', 'Ramuna', 'Ramune', 'Ramute', 'Rana', 'Ranāte', 'Randa', 'Randija', 'Raneta', 'Ranita', 'Ranta', 'Rasa', 'Rasita', 'Rasma', 'Rasmīte', 'Rasulīte', 'Rauza', 'Ravena', 'Ravita', 'Rebeka', 'Regija', 'Regīna', 'Regina', 'Reģīna', 'Regita', 'Reičela', 'Reina', 'Rena', 'Rēna', 'Renalda', 'Renāta', 'Renāte', 'Renate', 'Rendija', 'Renē', 'Reneta', 'Renija', 'Renita', 'Renta', 'Reta', 'Revita', 'Rezēda', 'Rezenda', 'Rezija', 'Rēzija', 'Rianda', 'Riandra', 'Rieta', 'Rigmora', 'Rigonda', 'Rikarda', 'Rima', 'Rimanta', 'Rimma', 'Rimona', 'Rimonda', 'Rimvalda', 'Rina', 'Rinalda', 'Rineta', 'Rinete', 'Ringla', 'Rinta', 'Rinvalda', 'Riona', 'Rita', 'Ritija', 'Ritma', 'Roberta', 'Robertīne', 'Robija', 'Robina', 'Rode', 'Roēna', 'Rogate', 'Roksana', 'Rolanda', 'Rolande', 'Rolanta', 'Rolita', 'Roma', 'Romalda', 'Romanda', 'Romānija', 'Romāra', 'Romena', 'Romēna', 'Rometa', 'Romija', 'Romina', 'Romualda', 'Romuta', 'Romvalda', 'Rona', 'Ronalda', 'Ronta', 'Rosita', 'Rosma', 'Rosvita', 'Rota', 'Rovena', 'Rovēna', 'Roza', 'Rozālija', 'Rozalija', 'Roze', 'Rozemarija', 'Rozita', 'Rozīte', 'Rozmarija', 'Rozvita', 'Ruāna', 'Ruda', 'Rudi', 'Rudīte', 'Rufina', 'Rusanda', 'Ruslana', 'Rusudana', 'Rūta', 'Ruta', 'Rūte', 'Rūtiņa', 'Ruzanna', 'Ruze',
        'Sabīna', 'Sabīne', 'Sabine', 'Sabrīna', 'Sagita', 'Saida', 'Saiga', 'Saija', 'Saila', 'Sailita', 'Saimona', 'Saira', 'Sairita', 'Saiva', 'Saksija', 'Salda', 'Salimona', 'Salimonija', 'Sallija', 'Salma', 'Salme', 'Salome', 'Salomeja', 'Salomija', 'Salvija', 'Samanta', 'Samīra', 'Sana', 'Sanda', 'Sandija', 'Sandita', 'Sandra', 'Sandrīte', 'Saneta', 'Sangrita', 'Sanija', 'Sanita', 'Sanlija', 'Sannija', 'Santa', 'Santana', 'Santija', 'Santra', 'Sāra', 'Sarika', 'Sarita', 'Sarma', 'Sarme', 'Sarmīte', 'Sārtīte', 'Saulcerīte', 'Saule', 'Saulgaida', 'Saulīte', 'Saulstarīte', 'Saulvija', 'Sava', 'Savina', 'Savita', 'Seila', 'Selēna', 'Selga', 'Sēlija', 'Selīna', 'Selita', 'Sella', 'Sellija', 'Selma', 'Selva', 'Senda', 'Sendija', 'Sendra', 'Senija', 'Senora', 'Serafima', 'Serafina', 'Serena', 'Serlana', 'Sevda', 'Severīna', 'Sholastika', 'Sholostika', 'Siandra', 'Sianta', 'Siāra', 'Sibilla', 'Sidija', 'Sidnija', 'Sidonija', 'Sigeta', 'Sigija', 'Sigita', 'Siglinda', 'Siglinde', 'Sigma', 'Signa', 'Signe', 'Signeja', 'Signejana', 'Signese', 'Signeta', 'Signija', 'Signita', 'Sigrīda', 'Sigrija', 'Sigrūna', 'Siguta', 'Sigute', 'Sijanda', 'Silga', 'Silja', 'Silva', 'Silvana', 'Silvestra', 'Silveta', 'Silvija', 'Silvita', 'Simona', 'Simoneta', 'Sinatra', 'Sinda', 'Sindija', 'Sindra', 'Singa', 'Singita', 'Singrita', 'Singūna', 'Sinilga', 'Sinita', 'Sinta', 'Sinti', 'Sintija', 'Sirdsvalda', 'Sirdvalda', 'Sīringa', 'Sirje', 'Sivija', 'Sjuzanna', 'Skaidra', 'Skaidre', 'Skaidrīte', 'Skara', 'Skārleta', 'Skolastika', 'Skolestika', 'Skolostika', 'Slanda', 'Smaida', 'Smaidiņa', 'Smaidīte', 'Smaidra', 'Smuidra', 'Smuidrīte', 'Snežana', 'Sņežana', 'Sņežanna', 'Snežanna', 'Sniedze', 'Sniedzīte', 'Sniga', 'Sofija', 'Sofja', 'Solanža', 'Solita', 'Solomeja', 'Solomija', 'Solomonija', 'Solumeja', 'Solvega', 'Solvēga', 'Solveiga', 'Solveta', 'Solvija', 'Solvita', 'Soņa', 'Sondra', 'Sonija', 'Sonita', 'Sonora', 'Sorenta', 'Spārīte', 'Spīdola', 'Spodra', 'Spodrīte', 'Spulga', 'Staņislava', 'Stanislava', 'Stase', 'Stasija', 'Stasja', 'Stefanīda', 'Stefānija', 'Stefanija', 'Steidzīte', 'Steiga', 'Stella', 'Stepanīda', 'Stepānija', 'Stīna', 'Stīne', 'Strauja', 'Straumīte', 'Strauta', 'Sulamīte', 'Susanna', 'Suzana', 'Suzanna', 'Svanhilda', 'Sveta', 'Svetlana',
        'Šarlota', 'Šarlote', 'Šeila', 'Šeila', 'Šeilija', 'Šelda', 'Šellija', 'Širiija', 'Širleja',
        'Tabita', 'Tabite', 'Tahmina', 'Taīda', 'Taiga', 'Taila', 'Taimira', 'Taisa', 'Taisija', 'Taive', 'Tāla', 'Tāle', 'Tālija', 'Talija', 'Talita', 'Tālivalda', 'Tālrita', 'Tamāra', 'Tamara', 'Taņa', 'Tanita', 'Tatjana', 'Tea', 'Teika', 'Teiksma', 'Tekla', 'Telma', 'Teodora', 'Teofīla', 'Teofile', 'Teofīlija', 'Teresa', 'Terēsa', 'Terese', 'Terēse', 'Terēsija', 'Teresija', 'Terēza', 'Tereza', 'Terēze', 'Tereze', 'Terezija', 'Terēzija', 'Tesa', 'Tija', 'Tikla', 'Tīksma', 'Tilla', 'Tillija', 'Tīna', 'Tina', 'Tince', 'Tira', 'Toņa', 'Tone', 'Tonija', 'Tonita', 'Tora', 'Trauta', 'Trautiņa', 'Treisija', 'Trīna', 'Trīne', 'Trūde', 'Trūta', 'Trūte', 'Tullija', 'Turaida', 'Tusnelda',
        'Uga', 'Ulda', 'Uldze', 'Ulita', 'Uljana', 'Uļjana', 'Ulla', 'Ullija', 'Ulrika', 'Ulvija', 'Ulvita', 'Una', 'Unda', 'Undija', 'Undīna', 'Undīne', 'Undita', 'Unigunde', 'Unija', 'Unita', 'Urdze', 'Urdziņa', 'Ursula', 'Uršula', 'Uršule', 'Urzula', 'Ustinija', 'Ustiņja', 'Uva', 'Uve', 'Uzbete',
        'Ūna', 'Ūnika', 'Ūva',
        'Vaclava', 'Vaida', 'Vaila', 'Vaileta', 'Vaira', 'Vairita', 'Vairīte', 'Vaiva', 'Vaļa', 'Valda', 'Valdona', 'Valdone', 'Valentija', 'Valentīna', 'Valentina', 'Valentīne', 'Valeriana', 'Valerianna', 'Valērija', 'Valerija', 'Valerijana', 'Valerjana', 'Valfrīda', 'Valīda', 'Valija', 'Valisa', 'Valita', 'Vallida', 'Vallija', 'Valma', 'Valta', 'Valtra', 'Valtraude', 'Valtrauta', 'Valtraute', 'Valve', 'Vanda', 'Vandze', 'Vaneranda', 'Vanesa', 'Vanese', 'Varenika', 'Varita', 'Varite', 'Varonika', 'Varvara', 'Vasilisa', 'Večella', 'Vega', 'Vegita', 'Veikla', 'Veiksma', 'Velda', 'Veldra', 'Veldza', 'Veldze', 'Velga', 'Velita', 'Velonija', 'Velta', 'Velte', 'Veltija', 'Veņa', 'Vena', 'Vēna', 'Vencislava', 'Venda', 'Vendeta', 'Vendija', 'Venefrīda', 'Venēra', 'Venera', 'Veneranda', 'Venerande', 'Veneta', 'Venija', 'Venīna', 'Veniranda', 'Venita', 'Venjamina', 'Venta', 'Vera', 'Vēra', 'Veranika', 'Verēna', 'Verena', 'Vergenija', 'Verija', 'Verita', 'Veronija', 'Veronika', 'Vēsma', 'Vēsmiņa', 'Veta', 'Vētra', 'Viāna', 'Vianta', 'Vicenta', 'Vida', 'Vidaga', 'Vidaija', 'Vide', 'Vīdega', 'Vīga', 'Vigda', 'Vigeta', 'Vigija', 'Viģīlija', 'Vigilija', 'Vigita', 'Vigra', 'Vija', 'Vijolīte', 'Vika', 'Vikija', 'Viktora', 'Viktorija', 'Viktorina', 'Vila', 'Vilenta', 'Vilfrida', 'Vilhelma', 'Vilhelmīna', 'Vilhelmīne', 'Vilhelmine', 'Vilija', 'Vilita', 'Vilja', 'Viljanta', 'Villija', 'Vilma', 'Vilonija', 'Vilora', 'Vīna', 'Vinca', 'Vincenta', 'Vincentīna', 'Vincentīne', 'Vīne', 'Vineta', 'Vinete', 'Vingra', 'Vinifreda', 'Vinija', 'Vinita', 'Vinnija', 'Vinta', 'Vintra', 'Viola', 'Violanda', 'Violanta', 'Violenta', 'Violeta', 'Viorika', 'Virdžinija', 'Virēna', 'Virga', 'Virgenija', 'Virgīna', 'Virgīne', 'Virgīnija', 'Virginija', 'Virģīnija', 'Virma', 'Virta', 'Visija', 'Visma', 'Visvalda', 'Vita', 'Vitālija', 'Vitalina', 'Vitalisa', 'Vitija', 'Vitnija', 'Vitolda', 'Viva', 'Vivanta', 'Viveja', 'Viveta', 'Viviāna', 'Viviana', 'Vivija', 'Vivina', 'Vivita', 'Vizbule', 'Vizbulīte', 'Vizma', 'Vlada', 'Vladilena', 'Vladimira', 'Vladislava', 'Vladlena', 'Volga',
        'Zabīne', 'Zaiga', 'Zallija', 'Zana', 'Zanda', 'Zandra', 'Zane', 'Zanga', 'Zanita', 'Zanna', 'Zanza', 'Zara', 'Zarina', 'Zelda', 'Zelga', 'Zelma', 'Zelta', 'Zeltiņa', 'Zeltīte', 'Zemfira', 'Zemīra', 'Zemlita', 'Zena', 'Zenaida', 'Zenita', 'Zenobija', 'Zenona', 'Zenta', 'Zēra', 'Zeta', 'Zete', 'Zetiņa', 'Zidija', 'Zidonija', 'Zidra', 'Ziedīte', 'Ziednese', 'Ziedone', 'Ziedonija', 'Ziedvalda', 'Ziga', 'Zigda', 'Zigeta', 'Zigfrīda', 'Zigfrida', 'Zigija', 'Zigita', 'Zigma', 'Zigmāra', 'Zigmunda', 'Zigna', 'Zigne', 'Zigra', 'Zigrīda', 'Zigrida', 'Zigrita', 'Zīle', 'Zilga', 'Zilgma', 'Zilgme', 'Zīlīte', 'Zilva', 'Zilvija', 'Zina', 'Zinaīda', 'Zinaida', 'Zinda', 'Zindra', 'Zinīda', 'Zinija', 'Zinovija', 'Zinta', 'Zintra', 'Zira', 'Zita', 'Zlata', 'Zofija', 'Zoja', 'Zola', 'Zolija', 'Zosja', 'Zuzana', 'Zuzanna', 'Zuze', 'Zvaigznīte',
        'Žaklīna', 'Žaklina', 'Žaklīne', 'Žana', 'Žaneta', 'Žanete', 'Žanija', 'Žanna', 'Žanneta', 'Žene', 'Ženija', 'Žermēna', 'Žermena', 'Žozefina', 'Žuanete', 'Žubīte',
    ];

    /**
     * {@link} https://lv.wikipedia.org/wiki/Kategorija:Latvie%C5%A1u_uzv%C4%81rdi
     */
    protected static $lastName = [
        'Abuls', 'Aizupe', 'Akmentiņš', 'Alksnis', 'Alunāns', 'Ancāns', 'Andžāns', 'Ankipāns', 'Aparjode', 'Apine', 'Apinis', 'Aploks', 'Apse', 'Apsītis', 'Arājs', 'Asars', 'Astra', 'Augstkalns', 'Augškalns', 'Auniņš', 'Auns', 'Auškāps', 'Auziņa', 'Auziņš', 'Avens', 'Avens', 'Avotiņš', 'Avots',
        'Ābele', 'Ābelīte', 'Ābola', 'Āboliņa', 'Āboliņš', 'Ābols', 'Āboltiņa', 'Āboltiņš', 'Ārgalis',
        'Bajārs', 'Baldzēns', 'Bāliņa', 'Bāliņš', 'Balode', 'Balodis', 'Baltgailis', 'Baltiņš', 'Banga', 'Bārbale', 'Bārda', 'Bargais', 'Barkāns', 'Barons', 'Baušķenieks', 'Bebris', 'Berģis', 'Bertāns', 'Bērziņa', 'Bērziņš', 'Bērzkalns', 'Bērzs', 'Bētiņš', 'Biezais', 'Birkavs', 'Birkerts', 'Birze', 'Birznieks', 'Bisenieks', 'Bite', 'Bitenieks', 'Bļodnieks', 'Bojārs', 'Brasla', 'Breikšs', 'Brencēns', 'Brice', 'Briede', 'Briedis', 'Broks', 'Brože', 'Buiķis', 'Buks', 'Bulis', 'Bumbiere', 'Burvis', 'Butāne', 'Butkus',
        'Cālītis', 'Caune', 'Caunītis', 'Celmiņa', 'Celmiņš', 'Celms', 'Ceplītis', 'Cērps', 'Cielēns', 'Ciemiņš', 'Cipruss', 'Cipulis', 'Cīrulis',
        'Čaklais', 'Čakste', 'Čevers', 'Čukste',
        'Dāboliņš', 'Daiders', 'Dālderis', 'Dambis', 'Dārziņš', 'Dārznieks', 'Deglavs', 'Dimants', 'Dobelis', 'Draviņš', 'Dravnieks', 'Dubra', 'Dukure', 'Dukurs', 'Dumpe', 'Dumpis', 'Dzelme', 'Dzelzītis', 'Dzenis', 'Dzenītis', 'Dzērve', 'Dzintars', 'Dzirne', 'Džeriņš',
        'Egle', 'Eglīte', 'Eglītis', 'Eiduka', 'Eisaks', 'Elksne', 'Endzelīna', 'Endzelīns', 'Endziņš', 'Eniņš', 'Ezeriņš',
        'Ēķis', 'Ērglis',
        'Freimanis',
        'Gaigals', 'Gaile', 'Gailis', 'Gailītis', 'Galviņš', 'Garanča', 'Gauja', 'Goba', 'Goppers', 'Gorkšs', 'Grantiņš', 'Graudiņš', 'Grauds', 'Grava', 'Grāvelis', 'Greste', 'Grēviņš', 'Grīva', 'Grūbe', 'Gruzītis', 'Gulbe', 'Gulbis',
        'Ģīlis', 'Ģirģens',
        'Igaunis', 'Ikauniece', 'Ikaunieks', 'Indriksone', 'Indriksons', 'Irbe',
        'Īvāns',
        'Jankausks', 'Jaudzems', 'Jaunzeme', 'Jaunzemis', 'Jaunzems', 'Jurjāns', 'Jūsmiņš',
        'Kadiķis', 'Kaijaks', 'Kaktiņš', 'Kalējs', 'Kalna', 'Kalnbērzs', 'Kalniņa', 'Kalniņš', 'Kalnozols', 'Kalns', 'Kalpaks', 'Kambala', 'Kantāns', 'Kants', 'Kaņeps', 'Karašausks', 'Kārkliņa', 'Kārkliņš', 'Kauliņš', 'Kauls', 'Kazlausks', 'Kazričs', 'Kirmuška', 'Kivlenieks', 'Klētniece', 'Klišāns', 'Kļava', 'Kļaviņa', 'Kļaviņš', 'Kociņš', 'Kokina', 'Kokins', 'Kokle', 'Kozlovskis', 'Kramiņš', 'Krastiņa', 'Krastiņš', 'Krauklis', 'Krieviņš', 'Krievs', 'Krollis', 'Krūkliņš', 'Krūmiņa', 'Krūmiņš', 'Krustiņš', 'Kubiļus', 'Kubuliņa', 'Kugrēns', 'Kukainis', 'Kukule', 'Kukulis', 'Kūlis', 'Kundziņš', 'Kurpnieks', 'Kursītis', 'Kusiņš', 'Kušķis', 'Kvēps',
        'Ķemere', 'Ķempe', 'Ķēniņš', 'Ķibilds', 'Ķuzis',
        'Ladusāns', 'Lāce', 'Lācis', 'Lagzdiņš', 'Laime', 'Laimiņš', 'Laizāne', 'Laizāns', 'Lapainis', 'Lapiņš', 'Lapsa', 'Latvis', 'Lauks', 'Lauskis', 'Laviņa', 'Laviņš', 'Lazda', 'Lazdiņš', 'Legzdiņš', 'Leitāns', 'Leitis', 'Leja', 'Lejiņš', 'Lejnieks', 'Lībietis', 'Līce', 'Līdaka', 'Lieģis', 'Lielais', 'Lielgalvis', 'Liepa', 'Liepiņa', 'Liepiņš', 'Liepkalne', 'Linga', 'Liniņš', 'Ločmele', 'Ločmelis', 'Logina', 'Logins', 'Loze', 'Lujāns', 'Lūkins', 'Lūriņa', 'Lūsis',
        'Ļaksa',
        'Mangulis', 'Matīsa', 'Mauriņa', 'Mediņš', 'Mednis', 'Melbārde', 'Melbārdis', 'Mellupe', 'Melngailis', 'Mētra', 'Mežaraups', 'Mežciems', 'Mežlauks', 'Mežulis', 'Miezis', 'Miezītis', 'Miglinieks', 'Misāns', 'Miķelsons', 'Muceniece', 'Mucenieks', 'Muciņš', 'Muižniece', 'Muižnieks', 'Muktupāvela', 'Muktupāvels', 'Mūrniece', 'Mūrnieks',
        'Neretniece', 'Niedra', 'Niedre',
        'Oliņš', 'Osis', 'Oškalns', 'Ošs', 'Ozola', 'Ozoliņa', 'Ozoliņš', 'Ozols',
        'Pabērzs', 'Paegle', 'Pauļuks', 'Pelšs', 'Peniķis', 'Petrausks', 'Pīrāgs', 'Plaude', 'Plaudis', 'Plotnieks', 'Plūme', 'Pļaviņš', 'Pļavniece', 'Podnieks', 'Poikāns', 'Polis', 'Pormalis', 'Prauliņa', 'Prauliņš', 'Priede', 'Priedīte', 'Pūce', 'Pujāts', 'Puķe', 'Pumpurs', 'Pūpols', 'Pupurs', 'Puriņš', 'Purnis', 'Purviņš', 'Putniņa', 'Putniņš', 'Putra',
        'Radziņa', 'Radziņš', 'Rancāns', 'Raņķis', 'Rapa', 'Rausis', 'Reinika', 'Reiniks', 'Reizniece', 'Repše', 'Riekstiņš', 'Rijnieks', 'Rītiņš', 'Robežnieks', 'Roga', 'Rokpelnis', 'Ronis', 'Roze', 'Roziņš', 'Rozītis', 'Rožlapa', 'Rubene', 'Rubenis', 'Rudzīte', 'Rudzītis', 'Rullis', 'Rūmnieks', 'Rūtiņš',
        'Sabonis', 'Saliņš', 'Salmiņš', 'Salnis', 'Saulietis', 'Saulīte', 'Saulītis', 'Sedlenieks', 'Segliņa', 'Segliņš', 'Seile', 'Seiļs', 'Sesks', 'Siliņa', 'Siliņš', 'Sīlis', 'Sīmanis', 'Sirmais', 'Skābardis', 'Skalbe', 'Skrastiņa', 'Skrastiņš', 'Skride', 'Skrinda', 'Skudra', 'Skuja', 'Skujenieks', 'Skujiņa', 'Skujiņš', 'Skulme', 'Sodums', 'Spridzāns', 'Sproģe', 'Sproģis', 'Sprūdžs', 'Spūlis', 'Stabiņš', 'Stalts', 'Staprāns', 'Stepiņš', 'Stradiņš', 'Straumanis', 'Straume', 'Straupe', 'Strautmane', 'Strautmanis', 'Strautnieks', 'Strazdiņš', 'Strazds', 'Strēlis', 'Strēlnieks', 'Strods', 'Sudmalis', 'Sudraba', 'Sukurs', 'Sukuts',
        'Šķēle', 'Šnepsts',
        'Tauriņš', 'Teilāne', 'Tērauda', 'Timma', 'Tīruma', 'Titāns', 'Turss',
        'Upenieks', 'Upītis', 'Upmale', 'Urtāns', 'Ušpelis', 'Uzuliņš',
        'Ūdentiņš', 'Ūders', 'Ūdre', 'Ūdris',
        'Vācietis', 'Vairogs', 'Vaišļa', 'Vaivods', 'Vanags', 'Varslavāns', 'Vasarietis', 'Vazdika', 'Vazdiks', 'Vecozols', 'Vecumnieks', 'Vecvagars', 'Vērdiņš', 'Vīgante', 'Vīksna', 'Vīksne', 'Vilcāne', 'Vilciņa', 'Vilciņš', 'Vilkaste', 'Vilks', 'Viļums', 'Vimba', 'Vītola', 'Vītoliņš', 'Vītols',
        'Zaķis', 'Zāle', 'Zālīte', 'Zālītis', 'Zaļupe', 'Zariņa', 'Zariņš', 'Zelčs', 'Zeltiņa', 'Zeltiņš', 'Zemdega', 'Zemgals', 'Zemītis', 'Zemzaris', 'Ziedonis', 'Ziemele', 'Ziemelis', 'Zīle', 'Zirnis', 'Znotiņš', 'Zvagulis', 'Zvejnieks', 'Zviedris', 'Zvirbulis', 'Zvirgzdiņš',
        'Žagars', 'Žukausks',
    ];

    public function driverLicence()
    {
        return static::bothify('??######');
    }

    public function passportNumber()
    {
        return static::bothify('??#######');
    }

    /**
     * National Personal Identity number (personas kods)
     *
     * @see https://en.wikipedia.org/wiki/National_identification_number#Latvia
     *
     * @return string on format XXXXXX-XXXXX
     */
    public function personalIdentityNumber(?\DateTime $birthdate = null)
    {
        if (!$birthdate) {
            $birthdate = DateTime::dateTimeThisCentury();
        }

        $year = $birthdate->format('Y');

        if ($year >= 2000 && $year <= 2099) {
            $century = 2;
        } elseif ($year >= 1900 && $year <= 1999) {
            $century = 1;
        } else {
            $century = 0;
        }

        $datePart = $birthdate->format('dmy');
        $serialNumber = static::numerify('###');

        $partialNumberSplit = str_split($datePart . $century . $serialNumber);

        $idDigitValidator = [1, 6, 3, 7, 9, 10, 5, 8, 4, 2];
        $total = 0;

        foreach ($partialNumberSplit as $key => $digit) {
            if (isset($idDigitValidator[$key])) {
                $total += $idDigitValidator[$key] * (int) $digit;
            }
        }

        $checksumDigit = (1101 - $total) % 11 % 10;

        return $datePart . '-' . $century . $serialNumber . $checksumDigit;
    }
}
