<?php

declare(strict_types=1);

namespace Faker\Extension;

/**
 * @experimental This class is experimental and does not fall under our BC promise
 */
final class ExtensionNotFound extends \LogicException
{
}
