<?php

namespace Faker\Provider\ar_EG;

class Color extends \Faker\Provider\Color
{
    protected static $safeColorNames = [
        'أسود', 'قرمزي', 'أخضر', 'كحلي', 'زيتوني',
        'أرجواني', 'أحمر', 'أزرق', 'فضي', 'ذهبي',
        'رمادي', 'أصفر', 'برتقالي', 'بني', 'أبيض', 'بنفسجى',
    ];

    /**
     * @see http://r7eq.com/Service/Design/ColorName/
     */
    protected static $allColorNames = [
        'أخضر فاتح',
        'أزرق فاتح',
        'أحمر فاتح',
        'أصفر فاتح',
        'بني فاتح',
        'رمادي فاتح',
        'أرجواني فاتح',
        'زيتوني فاتح',
        'كحلي فاتح',
        'قرمزي فاتح',
        'أسود فاتح',
        'بنفسجى فاتح',
        'برتقالي فاتح',
        'زيتوني داكن',
        'كحلي داكن',
        'أخضر داكن',
        'قرمزي داكن',
        'أزرق داكن',
        'أحمر داكن',
        'أرجواني داكن',
        'بنفسجى داكن',
        'بني داكن',
        'برتقالي داكن',
        'أصفر داكن',
        'رمادي داكن',
        'وردي',
        'زهري',
        'طوبي',
        'كستنائي',
        'عسلي',
        'نحاسي',
        'أسمر',
        'خشبي',
        'كريمي',
        'سكري',
        'ثلجي',
        'بيج',
        'ليموني',
        'فستقي',
        'كموني',
        'يروزي',
        'سماوي',
        'نيلي',
        'بحري',
        'فحمي',
        'زيتي',
        'عنابي',
    ];
}
