<?php

namespace Faker\Provider\nl_NL;

class Color extends \Faker\Provider\Color
{
    protected static $safeColorNames = [
        'zwart', 'kastanjebruin', 'donkergroen', 'marine', 'olijfgroen',
        'purper', 'groenblauw', 'limoen', 'blauw', 'zilver',
        'grijs', 'geel', 'fuchsia', 'cyaan', 'wit',
    ];

    protected static $allColorNames = [
        'Cyaan', 'Aquamarijn', 'Aquamarijn', 'Ultramarijn', 'Beige',
        'Zwart', 'Blauw', 'Blauwviolet', 'Bruin', 'Groen', 'Chocoladebruin',
        'Koraal', 'Korenbloemblauw', 'Vermiljoen', 'Cyaan', 'Donkerblauw',
        'Donkercyaan', 'Donkergrijs', 'Donkergroen', 'Donkergrijs',
        'Donkerkaki', 'Donkermagenta', 'Donkerolijfgroen', 'Donkeroranje',
        'Donkerrood', 'Donkerzalm', 'Donkerzeegroen', 'Donkerleigrijs',
        'Donkerleigrijs', 'Donkerturkoois', 'Donkerviolet', 'Dieproze',
        'Diep hemelsblauw', 'Vuurvaste baksteen', 'Fluweelwit', 'Bosgroen',
        'Fuchsia', 'Goud', 'Grijs', 'Donkergroen', 'Groengeel', 'Grijs',
        'Acaciaroze', 'Indisch rood', 'Indigo', 'Ivoor', 'Kaki', 'Lavendel',
        'Grasgroen', 'Lichtblauw', 'Lichtkoraal', 'Lichtcyaan', 'Lichtgrijs',
        'Lichtgroen', 'Lichtgrijs', 'Lichtroze', 'Lichtzalm', 'Lichtzeegroen',
        'Lichthemelsblauw', 'Lichtleigrijs', 'Lichtleigrijs', 'Staalblauw',
        'Lichtgeel', 'Limoen', 'Limoengroen', 'Linnen', 'Magenta', 'Kastanjebruin',
        'Middenblauw', 'Midlentegroen', 'Middenvioletrood', 'Midnachtsblauw',
        'Mint', 'Marine', 'Kant', 'Olijfgroen', 'Oranje', 'Oranjerood', 'Oranjerood',
        'Orchidee', 'Bleekgroen', 'Lichtturkoois', 'Roze', 'Pruim', 'Purper',
        'Rood', 'Koningsblauw', 'Zalm', 'Zandbruin', 'Zeegroen', 'Schelp', 'Sienna',
        'Zilver', 'Hemelsblauw', 'Leigrijs', 'Leigrijs', 'Sneeuwwit', 'Lentegroen',
        'Donkerstaalblauw', 'Groenblauw', 'Distel', 'Tomaat', 'Transparant', 'Turkoois',
        'Violet', 'Wit', 'Rookwit', 'Geel', 'Groengeel',
    ];
}
